///////////////////////////////////////////////////////////////////////////////
/// \file tecbcfunct.h
/// Header File with programming interface of TBarCode.
/// This header file contains the functions of the TBarCode-DLL (Windows) and 
/// TBarCode/X (UNIX).
/// \n
/// The TBarCode-DLL and TBarCode/X basically have the same
/// API except for some functions:
/// - Functions denoted with "Windows only" belong 
/// to the TBarCode-DLL API and are only available in Windows.
/// - Functions denoted with "UNIX only" belong to the TBarCode/X API and are 
/// only available in UNIX/Linux environments.
/// \n
/// This file does not need to be included in your source files, instead include 
/// either TBarCodeDLL.h (TBarCode-DLL in Windows) or tbarcodelib.h (TBarCode/X in UNIX).
/// \n\n
/// \author TEC-IT Datenverarbeitung GmbH
/// \author Wagnerstr. 6, A-4400 Steyr, AUSTRIA/EUROPE
/// \author http://www.tec-it.com
/// \author Copyright&copy; by TEC-IT Datenverarbeitung GmbH
/// \date    1996-2005
/// \version 6.0
/// \note This product is supported. Please send an email to support@tec-it.com
///////////////////////////////////////////////////////////////////////////////
#ifndef HEADERFILE_TBCFUNCT_H
#define HEADERFILE_TBCFUNCT_H

#ifdef TEC_WIN
  #undef TECIT_STDCALL
  /// Defines calling convention.
  /// \internal
  #define TECIT_STDCALL _stdcall
#else
  #undef TECIT_STDCALL
  /// Defines calling convention.
  /// \internal
  #define TECIT_STDCALL
#endif

#ifdef __cplusplus
  extern "C"
  {
#endif

///////////////////////////////////////////////////////////////////////////////
// Doxygen groups (or modules)
//
/// \defgroup General       Required Function Calls
///                         These function calls are the absolute minimum to produce a bar-code with standard settings. The bar-code
///                         can then be drawn on a device context using BCDraw() or written to file using BCPostscriptToFile() (or similar).
/// \defgroup Barcode       Symbology  & Data-Input
///                         Functions for changing the general bar-code properties. Call them after BCAlloc() but before BCCreate()
/// \defgroup Escape        Escape Sequences
///                         TBarCode is able to interpret so-called escape sequences in the input data. 
///                         This escape sequence translation is disabled per default. An escape sequence is a sequence of characters starting with a backslash \\. 
/// \defgroup Valid         Data Validation
///                         Functions for validating bar-code data.
/// \defgroup Appearance    Appearance
///                         Modify the general appearance of a bar-code with these functions.
/// \defgroup Human         Human Readable Text
///                         Functions for the human readable text of a bar-code.
/// \defgroup Check         Check-Digits
///                         Modifies the behavior of TBarCode regarding check-digit computation.
/// \defgroup Module        Module Width 
///                         Functions for specifying the module width manually. Under normal circumstances TBarCode computes the module width automatically. For some applications this standard behavior must be changed.
/// \defgroup Ratio         Bar:Space Print-Ratio
///                         Modify the so-called print-ratio of a bar-code with these functions. TBarCode uses the standard-print ratio for each bar-code symbology. Some industry standards enorce the implementation of special print-ratios.
/// \defgroup Quiet         Quiet-Zone
///                         Beside in EAN and UPC bar-codes, TBarCode does not include quiet-zones into the generated bar-code. The functions available in this section provide an easy way to add quiet-zones to the bar-codes.
/// \defgroup Quality       Bar-Code Quality 
///                         These functions supports the user when optimizing bar-code quality (and therefore enhancing readability). 
/// \defgroup Draw          Drawing Bar-Codes 
///                         Drawing or printing a bar-code onto a device via a device context.
///                         \note For Windows only.
/// \defgroup Save          Saving Bar-Codes 
///                         Save generated bar-codes as various graphic files. Beside graphic formats TBarCode supports PCL and Postscript. These function-group is of special interest for all users dealing with web-applications.
/// \defgroup Clipboard     Clipboard
///                         Copy generated bar-codes onto the clipboard 
///                         \note For Windows only.
/// \defgroup Callback      Customized Drawing 
///                         The standard functionality of TBarCode for drawing/saving bar-codes may be customized with these call-back functions. For simple bar-code generating/bar-code printing applications these call-back functions are <b>not</b> required.
/// \defgroup Char          Bar-Code Characteristics 
///                         Functions for retrieving specific bar-code characteristics. 
///                         \note All of these functions are optional - but must be called after BCCreate().
/// \defgroup 2of5          Code 2 of 5 Interleaved 
///                         These functions are used for modifying the behavior of TBarCode when generating the 2 of 5 interleaved symbology. 
/// \defgroup PDF           2D Bar-Code: PDF417 and MicroPDF 
///                         These functions are used for modifying the behavior of TBarCode when generating PDF417, MacroPDF and MicroPDF symbologies. 
/// \defgroup Maxi          2D Bar-Code: MaxiCode 
///                         These functions are used for modifying the behavior of TBarCode when generating the Maxicode symbology. 
/// \defgroup DM            2D Bar-Code: Data Matrix 
///                         These functions are used for modifying the behavior of TBarCode when generating the Data Matrix symbology. 
/// \defgroup QR            2D Bar-Code: QR-Code 
///                         These functions are used for modifying the behavior of TBarCode when generating the QR-Code symbology. 
/// \defgroup CBF           2D Bar-Code: Codablock F 
///                         These functions are used for modifying the behavior of TBarCode when generating the Codablock-F symbology. 
/// \defgroup CompSym       2D Bar-Code: EAN / UCC Composite Symbology
///                         These functions are used for modifying the behavior of TBarCode when generating EAN.UCC-symbologies. 
/// \defgroup RSS           RSS (Reduced Space Symbology)
///                         These functions are used for modifying the behavior of TBarCode when generating RSS-symbologies. 
/// \defgroup Impl          TBarCode Implementation 
///                         These functions are dealing with TBarCode capabilities in a more or less generic way. Most of them are used in other software products from TEC-IT.
/// \defgroup Error         Error Handling
///                         Error handling functions. 
/// \defgroup Init          Advanced Initialization 
///                         Use of these functions is reserved to applications which are using a static libary of TBarCode. 
///                         \note A static library is available on request only. Please contact support@tec-it.com
///////////////////////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////////
//
//  Forwards
//
///////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////
/// Forward declaration of the internal used bar-code structure.
/// The exact layout of this structure is hidden.
typedef struct tag_BarCode  t_BarCode;

#ifdef TBARCODE_DLL
///////////////////////////////////////////////////////////////////////////////
/// Forward declaration of the internal used image generation structure.
/// The exact layout of this structure is hidden.
typedef struct tag_Victor   t_Victor;
#endif

///////////////////////////////////////////////////////////////////////////////
/// Data-type for error-codes.
/// Error-code 0 indicates successful operation
#define ERRCODE             LONG

///////////////////////////////////////////////////////////////////////////////
/// Data-type for custom row-drawing callback-function.
/// \see BCSetFuncDrawRow()
typedef ERRCODE             (CALLBACK *fn_DrawRow)  (VOID*, t_BarCode* const, HDC, HDC, RECT*);

///////////////////////////////////////////////////////////////////////////////
/// Data-type for custom bar-drawing callback-function.
/// \see BCDrawCB()
typedef ERRCODE             (CALLBACK *fn_DrawBar)  (VOID*, HDC, RECT*);
///////////////////////////////////////////////////////////////////////////////
/// Data-type for custom human readable text drawing callback-function.
/// \see BCDrawCB()
typedef ERRCODE             (CALLBACK *fn_DrawText) (VOID*, HDC, LPLOGFONTA, INT, INT, UINT, LPCSTR, INT);

/*typedef ERRCODE           (CALLBACK *fn_DrawText) 
                            (
                            VOID*,          // user data
                            HDC,            // device context
                            LPLOGFONTA,     // log font structure (Ansi char version)
                            INT,            // horizontal position
                            INT,            // vertical position
                            UINT,           // alignment (use windows defines)
                            LPCSTR,         // text to be drawn
                            INT             // text length
                            );
*/

///////////////////////////////////////////////////////////////////////////////
//
//  Constants
//
///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
/// Constant indicating a default value.
/// Used for determining or setting the default value of most relevant parameters.
#define BC_USEDEFAULT   -1

#ifdef TBARCODE_DLL
/*-----------------------------------------------------------------------------
    
        A T T A C H / D E T A C H

-----------------------------------------------------------------------------*/

////////////////////////////////////////////////////////////////////////////////
/// Initializes TBarCode for further use (Windows only). 
/// Required only for static library variants of TBarCode (not for DLLs). 
/// Must be called as first function.
/// \note Contact TEC-IT regarding the availability of TBarCode as static library
/// \note WINDOWS only (TBarCode DLL API).
/// \retval true    Initialization successful
/// \retval false   Initialization not successful
/// \ingroup Init
////////////////////////////////////////////////////////////////////////////////
BOOL TECIT_STDCALL   BCAttach 
(
);

////////////////////////////////////////////////////////////////////////////////
/// Attach library to given instance (Windows only).
/// Required only for static library variants of TBarCode. 
/// Must be called as first function.
/// \note Contact TEC-IT regarding the availability of TBarCode as static library
/// \note WINDOWS only (TBarCode DLL API).
/// \retval true    Initialization successful
/// \retval false   Initialization not successful
/// \ingroup Init
///////////////////////////////////////////////////////////////////////////////
BOOL TECIT_STDCALL   BCAttachInstance 
(
HINSTANCE       hInstance   ///< IN: Instance handle of process
);

//////////////////////////////////////////////////////////////////////////////
/// Detach library from process (Windows only).
/// Required only for static library variants of TBarCode (not for DLLs). 
/// Must be called as last function.
/// \note Contact TEC-IT regarding the availablity of TBarCode as static library
/// \note WINDOWS only (TBarCode DLL API).
/// \retval true    De-initialization successful
/// \retval false   De-initialization not successful
/// \ingroup Init
///////////////////////////////////////////////////////////////////////////////
BOOL TECIT_STDCALL   BCDetach();
#endif // TBARCODE_DLL

/*----------------------------------------------------------------------------/
    
        I N I T / D E I N I T - Functions

/----------------------------------------------------------------------------*/

#ifdef LIBTBARCODE
//////////////////////////////////////////////////////////////////////////////
/// Initializes TBarCode/X (UNIX only).
/// Must be called after loading TBarCode/X library and before calling any other 
/// functions from TBarCode/X.
/// \note UNIX only (TBarCode/X API).
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup General
//////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC
ERRCODE     TECIT_STDCALL   BCInitLibrary
(
LPCSTR                      szPath      ///< IN: Directory in which the TBarCode license files are located.
                                        ///<     \n
                                        ///<     TBarCode/X can be licensed per application using BCLicenseMe()
                                        ///<     or globally on a system. To license TBarCode/X globally 
                                        ///<     a valid license file named 'license.ini' must be placed in the path
                                        ///<     specified with szPath.
                                        ///<     \n
                                        ///<     The default location for 'license.ini' is '/usr/local/share/tbarcode2'.
);

//////////////////////////////////////////////////////////////////////////////
/// De-initializes TBarCode/X (UNIX only).
/// Must be called before terminating the application or before unloading
/// TBarCode/X library.
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup General
//////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC
ERRCODE     TECIT_STDCALL   BCDeInitLibrary();
#endif // LIBTBARCODE

//////////////////////////////////////////////////////////////////////////////
/// Allocates and initializes bar-code structure.
/// Must be called as first function before any other call using pBarCode.
/// This function allocates and initializes the internal bar-code structure to 
/// store all parameters. It sets the pointer that you pass to this function. 
/// For each bar-code you want to use simultaneously, you have to call this 
/// function to get an appropriate handle (pBarCode).
///
/// \see BCFree()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup General
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCAlloc
(
t_BarCode**                 pBarCode    ///< I/O: Pointer to bar-code structure
                                        ///< only valid if return value is ErrOk (0)

);

//////////////////////////////////////////////////////////////////////////////
/// De-initializes bar-code structure.
/// Must be called as last function and frees all resources used by pBarCode. 
/// The pointer pBarCode must not be used after this call.
///
/// \see BCAlloc()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup General
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCFree
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

/*----------------------------------------------------------------------------/
    
        P R O P E R T Y   S E T / G E T - Functions

/----------------------------------------------------------------------------*/

//////////////////////////////////////////////////////////////////////////////
/// Sets the color the of bar-code.
/// Specifies the color of the bars (or dots) of the bar-code.
/// \see BCGetColorBC()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Appearance
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSetColorBC
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
COLORREF                    color       ///< IN : RGB color value
);

///////////////////////////////////////////////////////////////////////////////
/// Gets the current bar-code color.
/// Returns currently adjusted value.
/// \see BCSetColorBC()
/// \retval COLORREF    Current value. Black is the default
/// \ingroup Appearance
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
COLORREF    TECIT_STDCALL   BCGetColorBC
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

//////////////////////////////////////////////////////////////////////////////
/// Sets the color of the human readable text.
/// Used only when drawing of the human-readable text is activated (see BCSetPrintText())
/// \see BCGetColorFont(), BCSetPrintText()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Appearance
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSetColorFont
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
COLORREF                    color       ///< IN : RGB color value
);

///////////////////////////////////////////////////////////////////////////////
/// Gets the current color of the human readable text.
/// Returns currently adjusted value.
/// \see BCSetColorFont()
/// \retval COLORREF        Current value. Black is the default
/// \ingroup Appearance
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
COLORREF    TECIT_STDCALL   BCGetColorFont
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

//////////////////////////////////////////////////////////////////////////////
/// Sets the color of the bar-code background.
/// Specifies the background color of the bar-code. This color is used to draw 
/// the spaces of the bar-code when the BackStyle is set to OPAQUE.
/// \see BCGetColorBk(), BCSetBkMode()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Appearance
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSetColorBk
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
COLORREF                    color       ///< IN : RGB color value
);

///////////////////////////////////////////////////////////////////////////////
/// Gets the current background  color.
/// Returns currently adjusted value.
/// \see BCSetColorBk()
/// \retval COLORREF        Current value. White is the default
/// \ingroup Appearance
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
COLORREF    TECIT_STDCALL   BCGetColorBk
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

//////////////////////////////////////////////////////////////////////////////
/// Sets background drawing mode.
/// Specifies whether the bar-code background should be transparent or opaque.
/// If set to transparent, no background color is used.
/// \see BCGetBkMode()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Appearance
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSetBkMode
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LONG                        nMode       ///< IN : Background mode
                                        ///<
                                        ///< - 1: Transparent
                                        ///< - 2: Opaque (this is the default)
);

///////////////////////////////////////////////////////////////////////////////
/// Gets current background drawing mode. 
/// Returns currently adjusted value.
/// \see BCSetBkMode() 
/// \retval 1   Transparent
/// \retval 2   Opaque (background is filled with background color). This is the default.
/// \ingroup Appearance
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGetBkMode
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Selects the method for drawing bars.
/// Sets the GDI drawing-method used for painting the bars. 
/// TBarCode normally draw bars with specialized GDI-functionality. Some printer drivers 
/// do not handle this method correctly (invisible or too short bars). 
/// If this happens activate the conventional method (bars are drawn as filled rectangles).
/// The conventional method may result in decreased bar-code quality for devices with low 
/// output resolution. 
/// \see BCGetDrawMode()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Draw
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSetDrawMode
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
BOOL                        bUseGDIRect ///< IN : Use GDI DrawRect for drawing 
                                        ///<
                                        ///< - true: Conventional method is used (filled rectangles)
                                        ///< - false: Advanced (and more accurate) method is used. This is the default.
);

///////////////////////////////////////////////////////////////////////////////
/// Gets current method for drawing bars.
/// Returns currently adjusted value.
/// \see BCSetDrawMode() 
/// \retval true    Conventional method is used (drawing filled rectangles)
/// \retval false   Advanced and more accurate method is used. This is the default.
/// \ingroup Draw
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
BOOL        TECIT_STDCALL   BCGetDrawMode
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets quiet-zones and units used for quiet-zones.
/// Specifies the required quiet-zone and the respective measurement units. A quiet zone is an unprinted area to the left / right of a linear bar-code. 2D-codes may require quiet-zones at the top/bottom too.
/// Quiet-zone functionality is currently implemented for linear bar-codes (left and right side) and for Data Matrix (all sides)
/// \see BCGetQuietZone()
/// \note Currently you can specify the quiet zone in [modules] only, so the width of the quiet zone depends on the module width (respectively narrow bar width X)
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Quiet
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC
ERRCODE     TECIT_STDCALL   BCSetQuietZone
(
t_BarCode*  const           pBarCode,       ///< IN : Pointer to bar-code structure        
LPRECT      const           prQuietZone,    ///< IN : Pointer to rectangle that specifies quietzone       
e_QZMUnit                   eQZMUnit        ///< IN : Unit for quietzone-values (mm, Modules, mils...)
);

///////////////////////////////////////////////////////////////////////////////
/// Gets current quiet-zone settings.
/// Returns currently adjusted value.
/// \see BCSetQuietZone()
/// \retval LPCRECT rectangle specifying the quiet-zone dimensions [modules].
/// \ingroup Quiet
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LPCRECT     TECIT_STDCALL   BCGetQuietZone
(
t_BarCode*  const           pBarCode       ///< IN : Pointer to bar-code structure     
);

///////////////////////////////////////////////////////////////////////////////
/// Gets current measurement unit used for specifying quiet-zones.
/// Returns currently adjusted value.
/// \see BCSetQuietZone()
/// \retval e_QZMUnit   Unit enumerator. 
/// \ingroup Quiet
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
e_QZMUnit     TECIT_STDCALL BCGetQuietZoneUnit
(
t_BarCode*  const           pBarCode       ///< IN : Pointer to bar-code structure     
);

///////////////////////////////////////////////////////////////////////////////
/// Sets the font for the human readable text (Windows only). 
/// Sets the font characteristics used for the human readable text. 
/// \note Pass a LOGFONT structure whose lfHeight field must be set to the Point size [1/72"] of the font.
/// \note Usage for printing and BCSaveImage()
/// \code
/// LOGFONTA font size = size [point]  
/// \endcode
/// \note Usage for painting on the screen device context 
/// \code
/// pFont->lfHeight = -MulDiv (pointsize, dc. GetDeviceCaps (LOGPIXELSY), 72);
/// \endcode
/// \note We are using 8 Byte alignment!
/// \note Windows only (TBarCode DLL API)
/// \see BCGetLogFont()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Human
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSetLogFont
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
const LOGFONTA*             lf          ///< IN : Pointer to LOGFONT structure
);

///////////////////////////////////////////////////////////////////////////////
/// Gets current font for human readable text (Windows only).
/// Returns currently adjusted value.
/// \note We are using 8 Byte alignment!
/// \note Windows only (TBarCode DLL API)
/// \see BCSetLogFont()
/// \retval LOGFONT*    Pointer to LOGFONT structure.
/// \ingroup Human
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LOGFONTA*   TECIT_STDCALL   BCGetLogFont
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets the font for human readable text (UNIX only).
/// The name of the font depends on the output format, for example:\n
///
/// - Postscript accepts names such as \c Helvetica, \c Courier, \c Times-Roman, \c Helvetica-Bold, etc.\n
/// - PCL accepts names such as \c 16602 (for Helvetica), \c 4101 (for Times), etc. \n
///
/// Consult a Postscript or PCL reference for more information.
/// \note UNIX only (TBarCode/X API).
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Human
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC
ERRCODE TECIT_STDCALL  BCSetFontName
(
t_BarCode* const  pBarCode,       /* IN : Ptr To Barcode-Definition */
const CHAR*       szName          /* IN : fontname */
);


///////////////////////////////////////////////////////////////////////////////
/// Gets the current font for human readable text (Unix only).
/// 
/// \note UNIX only (TBarCode/X API).
/// \retval CHAR*    Name of font as a zero-terminated string.
/// \ingroup Human
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC
CHAR* TECIT_STDCALL  BCGetFontName
(
t_BarCode* const  pBarCode      /* IN : Ptr To Barcode-Definition  */
);

///////////////////////////////////////////////////////////////////////////////
/// Sets the font size [points] for human readable text (Unix only).
/// When no size is set a suitable font size is automatically determined depending
/// on the bar-code type and bar-code dimensions.
/// \note UNIX only (TBarCode/X API).
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Human
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC
ERRCODE TECIT_STDCALL  BCSetFontHeight
(
t_BarCode* const  pBarCode,       /* IN : Ptr To Barcode-Definition */
INT               nHeight         /* IN : font height */
);

///////////////////////////////////////////////////////////////////////////////
/// Gets the font size [points] for human readable text (Unix only).
/// Returns currently adjusted value.
/// \note UNIX only (TBarCode/X API).
/// \retval INT    Font size in points.
/// \ingroup Human
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC
INT TECIT_STDCALL  BCGetFontHeight
(
t_BarCode* const  pBarCode      /* IN : Ptr To Barcode-Definition */
);

///////////////////////////////////////////////////////////////////////////////
/// Chooses the required bar-code type (symbology).
/// Specifies the type of the bar-code to be generated (the so-called symbology). 
/// Look at the Bar-Code Reference to get an overview of the enumerations.
/// The default symbology used by TBarCode is Code128.
/// \see BCGetBCType()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Barcode
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSetBCType
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
e_BarCType                  eType       ///< IN : bar-code type (bar-code symbology)
);

///////////////////////////////////////////////////////////////////////////////
/// Gets the bar-code type (symbology) currently adjusted.
/// Returns currently adjusted value.
/// \see BCSetBCType()
/// \retval e_BarCType  Bar-code type (symbology) enumerator. Code128 is the default
/// \ingroup Barcode
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
e_BarCType  TECIT_STDCALL   BCGetBCType
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets bar-code text (ASCII version).
/// Specifies the data to be encoded as bar-code (also called utilizable data).
/// \n
/// The codeable strings (allowed characters) depend on the selected bar-code type: 
/// Some bar-codes support alphanumeric and some support only numeric characters. 
/// Some require a specific length of the string, some not. 
/// If the data provided is not valid for the selected bar-code an error is returned in BCCheck(). 
/// For a list of codeable characters for a specific bar-code type check out 
/// the separate document Bar-Code Reference (http://www.tec-it.com/documentation). 
/// \see BCGetText(), BCSetTextW(), BCIsTextUnicode(), BCGetTextLen()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Barcode
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSetText
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LPCSTR                      szText,     ///< IN : bar-code text                 
LONG                        nLen        ///< IN : length of input string, 
                                        ///< 
                                        ///<      - >0: Length of string is specifed in nLen
                                        ///<      - 0: TBarCode expects a \\0-terminated string
);

///////////////////////////////////////////////////////////////////////////////
/// Gets bar-code text (ASCII-version).
/// Returns the data to be encoded as bar-code (also called utilizable data).
/// \see BCSetText()
/// \retval LPCSTR  Text to be encoded as bar-code (ASCII)
/// \ingroup Barcode
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LPCSTR      TECIT_STDCALL   BCGetText
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Set bar-code text (UNICODE version).
/// Specifies the data to be encoded as bar-code (also called utilizable data).
/// This is the UNICODE respectively Wide Character version of BCSetText(). 
/// Reserved for future use (currently Unicode is not supported by any bar code type).
/// \see BCGetTextW(), BCSetText(), BCIsTextUnicode(), BCGetTextLen()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Barcode
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSetTextW
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LPCWSTR                     szText,     ///< IN : bar-code text                 
LONG                        nLen        ///< IN : length of input string, 
                                        ///< 
                                        ///<      - >0: Length of string is specifed in nLen
                                        ///<      - 0: TBarCode expects a \\0-terminated string
);

///////////////////////////////////////////////////////////////////////////////
/// Gets bar-code text (UNICODE-version).
/// Returns the data to be encoded as bar-code (also called utilizable data).
/// \see BCSetTextW()
/// \retval LPCWSTR Text to be encoded as bar-code (UNICODE)
/// \ingroup Barcode
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LPCWSTR     TECIT_STDCALL   BCGetTextW
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Returns type of current input data.
/// Determines if bar-code text was passed as UNICODE string or as ASCII string.
/// \see BCSetText(), BCSetTextW()
/// \retval true    The bar-code data was set with BCSetTextW(). 
/// \retval false   The bar-code data was set with BCSetText(). 
/// \ingroup Barcode
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
BOOL        TECIT_STDCALL   BCIsTextUnicode
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Gets length of bar-code input data.
/// Gets the length of the data to be encoded.
/// \see BCSetText(), BCSetTextW()
/// \retval LONG    Number of characters
/// \ingroup Barcode
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGetTextLen
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets format string applied to bar-code data prior encoding.
/// The format string is applied to the bar-code data before it is encoded.
/// Using the format string you can perform special operations (like including special control characters, 
/// subset switching, start/stop character control) easily.
/// \n 
/// Please refer to the Bar-Code Reference for more information.
/// \see BCSetText(), BCSetTextW(), BCGetFormat()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred
/// \ingroup Barcode
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSetFormat
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LPCSTR                      szFormat    ///< IN : Format string
);

///////////////////////////////////////////////////////////////////////////////
/// Gets current format string.
/// Returns currently adjusted value.
/// \see BCSetFormat()
/// \retval LPCSTR  Current format string. Default is NULL
/// \ingroup Barcode
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LPCSTR      TECIT_STDCALL   BCGetFormat
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Chooses check-digit method to be used.
/// Specifies the calculation method for the check-digit. Possible values are listed 
/// in the Bar-Code Reference.
/// \n
/// The method for the check-digit calculation used by TBarCode depends on the adjusted 
/// barcode type. In order to make the product as user-friendly as possible, 
/// a standard (default) method for each barcode type is supplied. 
/// Please note that for some bar codes there is no default check digit, but using 
/// a specific method is recommended in their specification. 
/// Some symbologies have an internal check sum (e.g. Modulo-103 used with Code-128). 
/// This check sum is always part of the generated bar code - regardless what the user specifies here. 
/// \attention Adust only check-digit methods, which are allowed or recommended for a specific symbology.
/// E.g. if a check-digit is generated, which cannot be encoded (e.g. due to limited character set of the bar-code) you will get an error. 
/// Also consider that it can be necessary that the scanner configuration is adapted to the check digit.
/// \see BCGetCDMethod(), BCCalcCD()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Check
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSetCDMethod
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
e_CDMethod                  eMethod     ///< IN : check-digit method          
);

///////////////////////////////////////////////////////////////////////////////
/// Gets the check-digit method currently in use.
/// Returns currently adjusted value.
/// \see BCSetCDMethod()
/// \retval eCDStandard No value set. This is the default. TBarCode computes the standard check-digit of the symbology.
/// \retval e_CDMethod  Otherwise
/// \ingroup Check
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
e_CDMethod  TECIT_STDCALL   BCGetCDMethod
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Returns all computed check-digits for the current bar-code.
/// Returns a string that contains all computed check-digits - in most cases 1 or 2 character(s). 
/// The string may contain unprintable characters (e.g. ASCII 0). 
/// Please note that symbology internal check sums (e.g. Mod-103 with Code-128) are not returned here.
/// Call this function after BCCalcCD() / BCCreate()
/// \see BCCalcCD(), BCCreate()
/// \retval LONG    Number of check-digits 
/// \retval -1      In case of error (buffer size to small)
/// \ingroup Check
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGetCheckDigits
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure   
LPSTR                       lpszCDText, ///< IO:  check-digit text buffer. If NULL this function returns only the number of check-digits.
LONG                        nSize       ///< IN : Buffer size of lpszCDText 
);

///////////////////////////////////////////////////////////////////////////////
/// Sets auto-correct option for Code 2 of 5 interleaved.
/// If set to true TBarCode inserts a leading zero if the number of data digits 
/// is odd when generating 2 of 5 interleaved.
/// 2of 5 interleaved is only able to encode an even number of digits. 
/// If this option is set to false BCCheck() returns with an error in the case 
/// of an odd number of input-digits.
/// \note Should always be true. 
/// \see BCGetAutoCorrect()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup 2of5
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSetAutoCorrect
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
BOOL                        bAutoCorrect///< IN : Autocorrect flag for 2of5 interleaved
                                        ///<
                                        ///< - true ... Enable auto-correct
                                        ///< - false ... Disable auto-correct
);

///////////////////////////////////////////////////////////////////////////////
/// Gets auto-correct option for Code 2 of 5 interleaved.
/// Returns currently adjusted value.
/// \see BCSetAutoCorrect()
/// \retval true            Enable auto-correct. This is the default
/// \retval false           Disable auto-correct
/// \ingroup 2of5
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
BOOL        TECIT_STDCALL   BCGetAutoCorrect
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets the rotation of the bar-code (counter-clockwise).
/// Rotates the bar-code in 90 steps counter-clockwise.
/// If you experience problems with the human readable text, make sure a suitable 
/// TrueType font is selected (the selected font must be support rotations).
/// \see BCGetRotation(), BCSetLogFont()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Appearance
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSetRotation
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
e_Degree                    eRotation   ///< IN : Rotation (counter-clockwise)                     
);

///////////////////////////////////////////////////////////////////////////////
/// Gets the current rotation of the bar-code.
/// Returns currently adjusted value.
/// \see BCSetRotation()
/// \retval deg0            No Rotation. This is the default  
/// \retval e_Degree        Rotation (counter-clockwise)       
/// \ingroup Appearance              
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
e_Degree    TECIT_STDCALL   BCGetRotation
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

//////////////////////////////////////////////////////////////////////////////
/// Sets human-readable text options.
/// Determines whether the human readable text should be printed. 
/// In addition it can be selected if the human-readable text is printed below or above the bar-code.
/// \see BCGetPrintText(), BCGetTextAbove()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Human
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSetPrintText
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure.
BOOL                        bReadable,  ///< IN : Print human readable readable text.
                                        ///< 
                                        ///<      - true:   Text is printed (this is the default)
                                        ///<      - false:  Text is not printed
BOOL                        bAbove      ///< IN : Print human readable text above bar-code.
                                        ///< 
                                        ///<      - true:   Text is printed above bar-code
                                        ///<      - false:  Text is printed below bar-code (this is the default)
);

///////////////////////////////////////////////////////////////////////////////
/// Determines if human-readable text is printed.
/// Returns currently adjusted value.
/// \see BCSetPrintText()
/// \retval true            Text is printed. This is the default
/// \retval false           Text is not printed
/// \ingroup Human
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
BOOL        TECIT_STDCALL   BCGetPrintText
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Determines if human-readable text is printed below or above the bar-code.
/// Returns currently adjusted value.
/// \see BCSetPrintText()
/// \retval true            Text is printed above bar-code
/// \retval false           Text is printed below bar-code. This is the default 
/// \ingroup Human
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
BOOL        TECIT_STDCALL   BCGetTextAbove
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets the width of the guard bars.
/// Sets the width of the guard bars [1/1000 mm]. Guard-bars are drawn below and above the bar-code and 
/// are used to avoid partial scans. See the Bar-Code Reference for more information. 
/// For some bar-code symbologies with synchronization bars (like EAN8) you must not enable guard bars.
/// \see BCGetGuardWidth()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Appearance
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSetGuardWidth
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LONG                        nGuardWidth ///< IN : Width of guard bars [1/1000 mm]. 
                                        ///< 0 if no guard bars are required (this is the default)
);

///////////////////////////////////////////////////////////////////////////////
/// Gets the current width of the guard bars.
/// Returns currently adjusted value.
/// \see BCSetGuardWidth()
/// \retval 0 No guard bars are printed. This is the default
/// \retval LONG Width of guard bars [1/1000 mm]. 
/// \ingroup Appearance
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGetGuardWidth
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets the distance between human readable text and the bar-code.
/// The standard text-distance is determined by TBarCode automatically (depending on the selected font).
/// Use this function to select another value. 
/// \see BCGetTextDist(), BCSetLogFont()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Human
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSetTextDist
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LONG                        nTextDist   ///< IN : Distance between bar-code and human readable text [1/1000 mm] (-1 ... reset to default)
);

///////////////////////////////////////////////////////////////////////////////
/// Gets the current distance between the human readable text and the bar-code.
/// Returns currently adjusted value.
/// \see BCSetTextDist()
/// \retval -1              No value set - distance is computed automatically. This is the default 
/// \retval LONG            Distance between bar-code and human readable text [1/1000 mm]        
/// \ingroup Human
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGetTextDist
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets the additional length of the synchronization bars (notches).
/// The term "notch" describes the synchronization bars used in some symbologies (like EAN, UPC, JAN, ...). 
/// These notches are a little bit longer than normal bars. The original length of these 
/// synchronization bars is determined by TBarCode automatically.
/// Use this function to specify an additional length of these bars. 
/// \see BCGetNotchHeight()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Appearance
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSetNotchHeight
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LONG                        nHeight     ///< IN : Additional notch height [1/1000 mm]. Negative values are allowed (-1 ... reset to default)
);

///////////////////////////////////////////////////////////////////////////////
/// Gets the current additional length of the synchronization bars (notches).
/// Returns currently adjusted value.
/// \see BCSetNotchHeight()
/// \retval -1          No value set. This is the default
/// \retval LONG        Otherwise [1/1000 mm]
/// \ingroup Appearance
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGetNotchHeight
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Activates/deactivates the translation of escape-sequences.
/// Defines if escape-sequences in the input data (e.g. "\n" in "123\n456") 
/// shall be translated before encoding takes place. If the translation of escape-sequences
/// is switched off, all characters are encoded "as-is". If it is activated, escape-sequences are
/// translated into their corresponding characters.
/// See Bar-Code Reference for more information.
/// \note In order to encode bar-code specific control characters (like subset 
/// selection in Code128) most likely escape sequences are required.
/// \see BCGetTranslateEsc(), BCSetText(), BCSetTextW()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Escape
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSetTranslateEsc
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
BOOL                        bTranslate  ///< IN : Translate escape sequences
                                        ///< 
                                        ///<      - true: Escape sequences (like "\n") are translated
                                        ///<      - false: Escape sequences are not translated (the default)
);

///////////////////////////////////////////////////////////////////////////////
/// Gets current state information regarding escape-sequence translation.
/// Returns currently adjusted value.
/// \see BCSetTranslateEsc()
/// \retval true    Escape sequences are translated
/// \retval false   Escape sequences are not translated. This is the default
/// \ingroup Escape
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
BOOL        TECIT_STDCALL   BCGetTranslateEsc
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Checks if the bar-code fits into the bounding rectangle. 
/// This property means that the bar-code must fit into the bounding rectangle during drawing. 
/// Background: When specifying a fixed module width the bar-code width (not the width of the bounding rectangle)
/// changes corresponding to the amount of data characters.
/// In addition, "MustFit" verifies if the module width is less than 1 pixel (which is treated as error in this case)
/// If "MustFit" is activated an error may be produced due to the above reasons during the BCDraw() method.
/// \see BCGetMustFit(), BCDraw()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Quality
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSetMustFit
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
BOOL                        bMustFit    ///< IN : must bar-code fit into 
                                        ///< 
                                        ///<      - true: Check if bar-code fits into bounding rectangle will be enabled
                                        ///<      - false: Check if bar-code fits into bounding rectangle will be disabled (the default)
);

///////////////////////////////////////////////////////////////////////////////
/// Returns if the bar-code must fit into the bounding rectangle. 
/// Returns currently adjusted value.
/// \see BCSetMustFit()
/// \retval true            TBarCode checks if bar-code fits into bounding rectangle 
/// \retval false           TBarCode does not check if bar-code fits into bounding rectangle. This is the default
/// \ingroup Quality
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
BOOL        TECIT_STDCALL   BCGetMustFit
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Optimize bar-code resolution. 
/// If this feature is activated, the module width will be adapted to the resolution of the output device by TBarCode.
/// All bars/spaces of a bar-code are computed in a way that only integer bar (space) widths are used. 
/// The bar-code will not be larger than the bounding-rectangle. The total width of the bar-code may shrink (compared to the Bounding rectangle). 
/// Keep care about the minimal size of the bar-code!
/// Using optimization the readability of the bar-code is (quite) independent from the given resolution. 
/// Using this options is important for bitmap formats or for small output resolutions (e.g. screen or dot matrix printers).
/// \n\n
/// \note Hints for saving the bar-code in Postscript format (EPS Vector): 
/// If the default dpi-value is used (not explicitly set), the module width will be changed in order to correspond to default EPS 72 dpi raster width.
/// The bar-code width will be adjusted, so that the module width is a multiple of 1/72" (point). So the narrow bar width fits into the standard 72 dpi raster of Postscript / EPS.
/// Needed if you want to convert the EPS output to a raster / bitmap image format in a second step (e.g. JPG used in web applications). Therefore you don't loose pixel information.
/// \see BCGetOptResolution()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Quality
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSetOptResolution
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
BOOL                        bOpt        ///< IN : Optimize bar-code for resolution
                                        ///< 
                                        ///<      - true: Optimization will be enabled
                                        ///<      - false: Optimization will be disabled (the default)
);

///////////////////////////////////////////////////////////////////////////////
/// Gets current bar-code optimizing behavior. 
/// Returns currently adjusted value.
/// \see BCSetOptResolution()
/// \retval                 true Optimization is enabled
/// \retval                 false Optimization is disabled. This is the default
/// \ingroup Quality
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
BOOL        TECIT_STDCALL   BCGetOptResolution
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets if bar-code is drawn mirrored (Windows only).
/// Mirrors bar-code. Ideal for printing bar-codes on transparent films. Used in pre-press applications.
/// \see BCGetMirror()
/// \note WINDOWS only (TBarCode DLL API).
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Appearance
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSetMirror
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
BOOL                        bMirror     ///< IN : Mirror bar-code 
                                        ///< 
                                        ///<      - true: Bar-code will be mirrored
                                        ///<      - false: Bar-code will be drawn normally (the default)
);

///////////////////////////////////////////////////////////////////////////////
/// Gets if bar-code is drawn mirrored (Windows only).
/// Returns currently adjusted value.
/// \see BCSetMirror()
/// \note WINDOWS only (TBarCode DLL API).
/// \retval \c true bar-code will be mirrored
/// \retval \c false bar-code will be drawn normally. This is the default
/// \ingroup Appearance
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
BOOL        TECIT_STDCALL   BCGetMirror
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets user defined resolution.
/// Sets output resolution to be used in bar code drawing / calculation functions.
/// If not set (default), the resolution of the available device context is used (e.g. screen resolution or printer resolution). 
/// Can be used to estimate the quality of a bar code for a specific output resolution (BCGetQuality()). 
/// For other purposes this function should be used careful, because bar code dimensions can change unexpectedly.
/// \see BCGetDPIHorz(), BCGetDPIVert()
/// \note Windows only.
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Appearance
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSetDPI
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LONG                        nDPIHorz,   ///< IN : User defined horizontal DPI (-1 ... reset to default)
LONG                        nDPIVert    ///< IN : User defined vertical DPI (-1 ... reset to default)
);

///////////////////////////////////////////////////////////////////////////////
/// Gets current user-defined horizontal resolution.
/// Gets current user-defined horizontal resolution.
/// \see BCSetDPI()
/// \note Windows only.
/// \retval LONG    Horizontal DPI
/// \ingroup Appearance
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGetDPIHorz
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Gets current user-defined vertical resolution.
/// Gets current user-defined vertical resolution.
/// \see BCSetDPI()
/// \note Windows only.
/// \retval LONG    Vertical DPI
/// \ingroup Appearance
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGetDPIVert
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets the human readable text.
/// This property is used to set the human readable text by your own. 
/// This function overrides the human readable text determined by TBarCode automatically 
/// (which is based on the bar-code data). 
/// \see BCGetDisplayText(), BCSetTextAlignment()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Human
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSetDisplayText
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LPCSTR                      szText      ///< IN : Display text (reset to default: null)                 
);

///////////////////////////////////////////////////////////////////////////////
/// Gets the current human readable text set with BCSetDisplayText().
/// Returns currently adjusted value.
/// \see BCSetDisplayText()
/// \retval NULL            No value set. This is the default
/// \retval LPCSTR          Human readable text
/// \ingroup Human
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LPCSTR      TECIT_STDCALL   BCGetDisplayText
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets a fixed module width (value is passed as string [0.001 mm]).
/// The module width is defined as the width of the smallest element (bar or space) 
/// a bar-code is using. Values are specified is 1/1000 mm. 
/// If the module width is not set explicitly (default), the module width is 
/// automatically adapted to the object size (Bounding rectangle) and the 
/// amount of data to be encoded. If a value is set, the width of the modules and 
/// therefore of the whole bar-code can be controlled (this may also influence 
/// the readability!). If set, the bar-code width depends on the amount of data 
/// encoded in the bar-code. For most bar-code symbologies the module 
/// width should not fall below 0.19 mm. When drawing (Paint) the size of the 
/// bounding rectangle must be wide enough to avoid clipping. 
/// \see BCSetModWidthN()
/// \note This method expects that the required module width is converted into a string [1/1000 mm]!
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Module
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSetModWidth
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LPCSTR                      szModWidth  ///< IN : Module width [1/1000 mm] (reset to default = "-1")
);

///////////////////////////////////////////////////////////////////////////////
/// Sets a fixed module width (value is passed as numeric parameter [0.001 mm]).
/// Sets a fixed module width passing a numeric value.
/// \see BCSetModWidth()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Module
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSetModWidthN
(
t_BarCode*  const           pBarCode,       ///< IN : Pointer to bar-code structure 
DOUBLE                      dModWidth       ///< IN : Module width [1/1000 mm] (-1 ... reset to default)           
);

///////////////////////////////////////////////////////////////////////////////
/// Gets the current module width (value is returned as string).
/// Returns currently adjusted value.
/// \see BCSetModWidth(), BCSetModWidthN()
/// \note This method converts the module width as string [1/1000 mm]!
/// \retval LPCSTR          String containing the module width [1/1000 mm]
/// \ingroup Module
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LPCSTR      TECIT_STDCALL   BCGetModWidth
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Set print-ratio string.
/// Specifies the print-ratio string for the width-relationship of the single bars and spaces. 
/// A format template used for this string is available in the property RatioHint (see BCGetRatioHint()). 
/// The ratio string looks like "1B:2B:...1S:2S" where 1B stands for the ratio-value for the most narrow bar, 1S for the ratio-value of the most-narrow space.
/// The number of values for bars (xB) and the number of values for the spaces (xS) depends on the current symbology. 
/// It is explained in more detail in the separate document Bar-Code Reference. 
/// \see BCGetRatio(), BCGetRatioHint()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Ratio
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSetRatio
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LPCSTR                      szRatio     ///< IN : Print-ratio string in the form "1:2:...1:2" (reset to default = null)
);

///////////////////////////////////////////////////////////////////////////////
/// Gets current print-ratio string.
/// Returns currently adjusted value.
/// \see BCSetRatio(), BCGetRatioHint(), BCGetRatioString()
/// \retval LPCSTR          Current ratio-string in format similar to "1B:2B:...1S:2S"
/// \ingroup Ratio
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LPCSTR      TECIT_STDCALL   BCGetRatio
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets bar-width reduction in percent (Pixel-Shaving).
/// Specifies the reduction of the bar-widths. The width of a bar in the bar-code is reduced by the 
/// given value in percent (with respect to the module width). This property is 
/// useful when printing on inkjet printers: On such printers the bars appear 
/// wider than specified because the ink spreads a little bit. You can compensate 
/// this effect by setting a bar-width reduction (also called "Pixel Shaving").
/// You have to play around to find suitable settings because this effect 
/// depends on the printer, on the used paper, and on the ink.
/// The printed module-width is equal to the theoretically optimal module-width multiplied with (100-nFactor) / 100. 
/// \see BCGetBarWidthReduction()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Quality
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSetBarWidthReduction
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LONG                        nFactor     ///< IN : Reduction in percent [0...100] (-1 ... reset to default)
);

///////////////////////////////////////////////////////////////////////////////
/// Gets current bar-width reduction value.
/// Returns currently adjusted value.
/// \see BCSetBarWidthReduction()
/// \retval LONG            Reduction in percent [0...100]. No reduction: 0 (this is the default)
/// \ingroup Quality
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGetBarWidthReduction
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Selects the alignment of the human readable text.
/// Selects the alignment of the human readable text. The default alignment is centered. 
/// \see BCGetTextAlignment()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Human
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSetTextAlignment
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
e_BCAlign                   eAlign      ///< IN : Text alignment enumerator
);

///////////////////////////////////////////////////////////////////////////////
/// Gets alignment of the human readable text.
/// Returns currently adjusted value.
/// \see SCSetTextAlignment()
/// \retval e_BCAlign       Alignment enumerator 
/// \ingroup Human
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
e_BCAlign   TECIT_STDCALL    BCGetTextAlignment
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Set call-back function for drawing a single row of a bar-code.
/// This functions informs TBarCode that drawing of a single bar-code row 
/// (one row for linear bar-codes, multiple rows for 2D or stacked codes) 
/// is done by the specified function. The specified function will be called from BCDraw() instead
/// of the built-in row-drawing functionality. Default: no callback function is used.
/// \n
/// Use this function to implement your custom drawing routines for specialized 
/// output requirements.
/// \see BCGetFuncDrawRaw()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Callback
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSetFuncDrawRow
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
fn_DrawRow                  fn,         ///< IN : Call-back function (reset to default = null)           
LPVOID                      pData       ///< IN : Custom data to pass to call-back function
);

///////////////////////////////////////////////////////////////////////////////
/// Gets call-back function for drawing a single row of a bar-code.
/// Returns currently adjusted function pointer.
/// \see BCSetFuncDrawRaw()
/// \retval NULL            No call-back function defined. This is the default
/// \retval fn_DrawRow      Otherwise
/// \ingroup Callback
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
fn_DrawRow  TECIT_STDCALL   BCGetFuncDrawRow
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets call-back function for drawing the human readable text of a bar-code.
/// This functions informs TBarCode that drawing of the human readable text 
/// (for linear bar-codes) is done by the specified function. 
/// \n
/// Use this function to implement your custom drawing routines for specialized 
/// output requirements. Default: no callback function is used.
/// \see BCGetFuncDrawText()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Callback
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSetFuncDrawText
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
fn_DrawText                 fn,         ///< IN : Call-back function (reset to default = null)          
LPVOID                      pData       ///< IN : Custom data to pass to call-back function
);

///////////////////////////////////////////////////////////////////////////////
/// Gets call-back function for drawing a text
/// Returns currently adjusted function pointer.
/// \see BCSetFuncDrawText()
/// \retval NULL        No call-back function defined. This is the default
/// \retval fn_DrawRow  Otherwise
/// \ingroup Callback
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
fn_DrawText  TECIT_STDCALL  BCGetFuncDrawText
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets number of PDF417 rows.
/// Sets the number of graphic rows for PDF417 to a fixed value. 
/// If not set, the number of rows is calculated automatically by TBarCode (this is the default).
/// \see BCGet_PDF417_Rows()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup PDF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_PDF417_Rows
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LONG                        nRows       ///< IN : number of rows [3..90] (-1 ... reset to default)       
);

///////////////////////////////////////////////////////////////////////////////
/// Gets number of PDF417 rows.
/// Returns currently adjusted value.
/// \see BCSet_PDF417_Rows()
/// \retval -1              No value set. This is the default
/// \retval [3...90]        Otherwise
/// \ingroup PDF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGet_PDF417_Rows
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets the number of PDF417 columns.
/// Sets the number of graphic columns [1...30] for PDF417 to a fixed value. 
/// If not set, the number of columns is calculated automatically by TBarCode (this is the default).
/// \see BCGet_PDF417_Columns()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup PDF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_PDF417_Columns
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LONG                        nColumns    ///< IN : number of columns [1..30] (-1 ... reset to default)    
);

///////////////////////////////////////////////////////////////////////////////
/// Gets number of PDF417 columns.
/// Returns currently adjusted value.
/// \see BCSet_PDF417_Columns()
/// \retval -1              No value set. This is the default
/// \retval [1...30]        Otherwise
/// \ingroup PDF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGet_PDF417_Columns
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets PDF417 error correction level.
/// Set the "Error Correction Level" for PDF417 to a fixed value. 
/// Possible values are [0...8] where 0 means only error recognition (no EC)
/// and 8 means the highest level of EC. 
/// If not set, the error correction level is chosen automatically by TBarCode.
/// \see BCGet_PDF417_ECLEvel()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup PDF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_PDF417_ECLEvel
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LONG                        nLevel      ///< IN : error correction level [0..8] (-1 ... reset to default)
);

///////////////////////////////////////////////////////////////////////////////
/// Gets current PDF417 error-correction level.
/// Returns currently adjusted value.
/// \see BCSet_PDF417_ECLEvel()
/// \retval -1              No value set. This is the default
/// \retval [0...8]         Otherwise
/// \ingroup PDF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGet_PDF417_ECLEvel
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets PDF417 row height to a fixed value.
/// Sets the height of a PDF417 row tow a fixed value [1/1000 mm]. 
/// If not set, the height is calculated automatically by TBarCode with respect 
/// to the bounding rectangle passed to BCDraw (..). 
/// \note If set, ensure that the bounding rectangle is big enough to avoid clipping.
/// \see BCGet_PDF417_RowHeight()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup PDF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_PDF417_RowHeight
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LONG                        nHeight     ///< IN : Row height [1/1000 mm] (-1 ... reset to default)      
);

///////////////////////////////////////////////////////////////////////////////
/// Gets PDF417 row-height.
/// Returns currently adjusted value.
/// \see BCSet_PDF417_RowHeight()
/// \retval -1              No value set. This is the default
/// \retval >0              Otherwise [1/1000 mm]
/// \ingroup PDF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGet_PDF417_RowHeight
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets PDF417 row to column ratio to a fixed value.
/// Sets the ratio between PDF417-rows and PDF417-columns. Does only work, if neither 
/// the value of PDF417-rows (BCSet_PDF417_Rows()) nor PDF417-columns (BCSet_PDF417_Columns()) are set to a constant value. 
/// If not set, the row:column ratio is chosen automatically by TBarCode (default).
/// \see BCGet_PDF417_RowColRatio()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup PDF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_PDF417_RowColRatio
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LPCSTR                      szRatio     ///< IN : Ratio-string "rows:columns" in the form "3:5" (reset to default = null)
);

///////////////////////////////////////////////////////////////////////////////
/// Gets PDF417 row to column ratio.
/// Returns currently adjusted value.
/// \see BCSet_PDF417_RowColRatio()
/// \retval NULL            No value set. This is the default
/// \retval String          Otherwise "rows:columns"
/// \ingroup PDF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LPCSTR      TECIT_STDCALL   BCGet_PDF417_RowColRatio
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets Macro-PDF417 segment index.
/// Index of the actual data segment in the symbol chain. 
/// Begin with 1 and increase for each additional symbol in the data chain.
/// \n
/// Macro PDF will be enabled only if the Segment index and the File ID are set. Default: Macro PDF is disabled.
/// \n
/// PDF417 allows user data to be spread across several symbols. 
/// This might be done if the data is too large to fit into a single symbol or 
/// for reasons of appearance and geometry.
/// \n
/// The so called "Macro PDF Control Block" carries additional control information 
/// that enables the reading device to reconstruct the data of all symbols in the correct order
/// Macro PDF functionality is also available for MicroPDF417.
/// \note When reading the encoded data with a bar code scanner, the index may be zero-based.
/// \see BCGet_PDF417_SegIndex()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup PDF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_PDF417_SegIndex
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LONG                        nSegInx     ///< IN : Segment index [1...99999] (reset to default/disable = -1)
);

///////////////////////////////////////////////////////////////////////////////
/// Gets current Macro-PDF417 segment index.
/// Returns currently adjusted value.
/// \see BCSet_PDF417_SegIndex()
/// \retval -1  No value set. This is the default
/// \retval [1...99999] Otherwise
/// \ingroup PDF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGet_PDF417_SegIndex
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets Macro PDF417 FileID.
/// The File-ID identifies all symbols, which belong to the same data chain. 
/// For reassembling, all data blocks having the same File-ID are concatenated 
/// in the order of increasing segment index.
/// \n
/// Macro PDF will be enabled only if the Segment-index and the File-ID are set. Default: MacroPDF is disabled.
/// \n
/// \see BCGet_PDF417_FileID()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup PDF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_PDF417_FileID
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LPCSTR                      szFileID    ///< IN : File ID string (-1 ... reset to default)
);

///////////////////////////////////////////////////////////////////////////////
/// Gets Macro PDF417 FileID.
/// Returns currently adjusted value.
/// \see BCSet_PDF417_FileID()
/// \retval NULL    No value set. This is the default
/// \retval String  Otherwise
/// \ingroup PDF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LPCSTR      TECIT_STDCALL   BCGet_PDF417_FileID
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Marks the actual symbol as the last one within the Macro PDF417 symbol chain.
/// Marks the current symbol as the last one within the actual symbol chain. 
/// This feature is used when generating Macro PDF417.
/// \see BCGet_PDF417_SegLast()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup PDF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_PDF417_SegLast
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
BOOL                        bSegLast    ///< IN : Is last segment
                                        ///<
                                        ///< - true: this is the last segment
                                        ///< - false: this is not the last segment
);

///////////////////////////////////////////////////////////////////////////////
/// Returns if this is the last symbol within a Macro PDF417 symbol-chain. 
/// Returns currently adjusted value.
/// \see BCSet_PDF417_SegLast()
/// \retval true    Current symbol is the last symbol within this chain 
/// \retval false   Otherwise
/// \ingroup PDF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
BOOL        TECIT_STDCALL   BCGet_PDF417_SegLast
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets Macro PDF417 File Name (optional).
/// Specifies file name (alphanumeric, variable length)
/// \n
/// Optional field to be encoded into the Macro PDF control header block. Default: unused.
/// \see BCGet_PDF417_FileName()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup PDF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_PDF417_FileName
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LPCSTR                      szFileName  ///< IN : File name (reset to default = null)                   
);

///////////////////////////////////////////////////////////////////////////////
/// Gets Macro PDF417 File Name.
/// Returns currently adjusted value.
/// \see BCSet_PDF417_FileName()
/// \retval NULL    No value set. This is the default
/// \retval String  Otherwise
/// \ingroup PDF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LPCSTR      TECIT_STDCALL   BCGet_PDF417_FileName
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets Macro PDF417 segment count (optional).
/// Specifies total number of data segments (numeric).
/// \n
/// Optional field to be encoded into the Macro PDF control header block. Default: unused.
/// \see BCGet_PDF417_SegCount()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup PDF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_PDF417_SegCount
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LONG                        nSegCount   ///< IN : segment count [1...99999] (-1 ... reset to default)
);

///////////////////////////////////////////////////////////////////////////////
/// Gets Macro PDF417 segment count.
/// Returns currently adjusted value.
/// \see BCGet_PDF417_SegCount()
/// \retval -1  No value set. This is the default
/// \retval [1...99999] Otherwise
/// \ingroup PDF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGet_PDF417_SegCount
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets Macro PDF417 Time Stamp (optional).
/// Specifies time stamp (elapsed time in seconds since January 1, 1970 00:00 GMT) (numeric)
/// \n
/// Optional field to be encoded into the Macro PDF control header block. Default: unused.
/// \see BCSet_PDF417_TimeStamp()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup PDF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_PDF417_TimeStamp
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LONG                        nTimeStamp  ///< IN : time stamp (-1 ... reset to default)                  
);

///////////////////////////////////////////////////////////////////////////////
/// Gets Macro PDF417 Time Stamp.
/// Returns currently adjusted value.
/// \see BCSet_PDF417_TimeStamp()
/// \retval -1  No value set. This is the default
/// \retval >0  Otherwise
/// \ingroup PDF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGet_PDF417_TimeStamp
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets Macro PDF417 Sender (optional).
/// Specifies sender (alphanumeric, variable length field)
/// \n
/// Optional field to be encoded into the Macro PDF control header block. Default: unused.
/// \see BCGet_PDF417_Sender()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup PDF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_PDF417_Sender
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LPCSTR                      szSender    ///< IN : Sender (reset to default = null)                      
);

///////////////////////////////////////////////////////////////////////////////
/// Gets Macro PDF417 Sender.
/// Returns currently adjusted value.
/// \see BCSet_PDF417_Sender()
/// \retval NULL    No value set. This is the default
/// \retval String  Otherwise
/// \ingroup PDF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LPCSTR      TECIT_STDCALL   BCGet_PDF417_Sender
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets Macro PDF417 Addressee (optional).
/// Specifies addressee (alphanumeric, variable length field)
/// \n
/// Optional field to be encoded into the Macro PDF control header block. Default: unused.
/// \see BCSet_PDF417_Adressee()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup PDF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_PDF417_Addressee
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LPCSTR                      szAddressee ///< IN : Addressee  (reset to default = null)                  
);

///////////////////////////////////////////////////////////////////////////////
/// Gets Macro PDF417 Adressee.
/// Returns currently adjusted value
/// \see BCSet_PDF417_Adressee()
/// \retval NULL    No value set. This is the default
/// \retval String  Otherwise
/// \ingroup PDF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LPCSTR      TECIT_STDCALL   BCGet_PDF417_Addressee
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets Macro PDF417 File Size (optional).
/// Specifies total number of Bytes encoded (numeric, variable length field)
/// \n
/// Optional field to be encoded into the Macro PDF control header block. Default: unused.
/// \see BCGet_PDF417_FileSize()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup PDF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_PDF417_FileSize
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LONG                        nFileSize   ///< IN : File Size  (-1 ... reset to default)                  
);

///////////////////////////////////////////////////////////////////////////////
/// Gets Macro PDF417 File Size.
/// Returns currently adjusted value 
/// \see BCSet_PDF417_FileSize()
/// \retval -1  No value set. This is the default
/// \retval >0  Otherwise
/// \ingroup PDF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGet_PDF417_FileSize
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets Macro PDF417 Check Sum (optional).
/// Sets 16-Bit CRC checksum (using CCITT-16 polynomial x16 + x12 + x5 + 1 over the entire data) 
/// \n
/// Optional field to be encoded into the Macro PDF control header block. Default: unused.
// \see BCGet_PDF417_CheckSum()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup PDF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_PDF417_CheckSum
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LONG                        nCheckSum   ///< IN : Check sum (-1 ... reset to default)                   
);

///////////////////////////////////////////////////////////////////////////////
/// Gets Macro PDF417 Check Sum.
/// Returns currently adjusted check-sum.
// \see BCSet_PDF417_CheckSum()
/// \retval -1  No value set. This is the default
/// \retval >0  Otherwise
/// \ingroup PDF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGet_PDF417_CheckSum
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets 2D Composite Component (= CC) Type.
/// Enables or disables generation of an EAN.UCC Composite Symbology and adjusts 
/// the type of the 2D composite component (CC-A, CC-B or CC-C). 
/// The CC is printed on top of the base symbol, which can be an RSS or an EAN-128 symbology. 
/// For usual applications (using EAN.UCC Composite) we recommend to set the CC-Type to eCC_Auto.
/// In this case TBarCode computes the optimal CC automatically. Default: eCC_None.
/// \see BCGet_2DCompositeComponent()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup CompSym
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_2DCompositeComponent
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
e_CCType                    eCCType     ///< IN : CC Type                      
);

///////////////////////////////////////////////////////////////////////////////
/// Gets adjusted 2D Composite Component.
/// Returns currently adjusted CC.
/// \see BCSet_2DCompositeComponent()
/// \retval eCC_None    No value set. This is the default
/// \retval e_CCType        Otherwise
/// \ingroup CompSym
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
e_CCType    TECIT_STDCALL   BCGet_2DCompositeComponent
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Specifies the operating mode for encoding data.
/// Specifies the operating mode for encoding data. Default is Mode 4.
/// \see BCGet_Maxi_Mode()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Maxi
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_Maxi_Mode
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LONG                        nMode       ///< IN : Used encoding mode [2..5]    
                                        ///<              
                                        ///<      - Mode 2: SCM Numeric - Structured Carrier Message (Postal Code only numeric, up to 9 digits)
                                        ///<      - Mode 3: SCM Alphanumeric - Structured Carrier Message (Postal Code alphanumeric, up to 6 characters)
                                        ///<      - Mode 4: For numeric and alphanumeric character sequences (Standard Error Correction). This is the default
                                        ///<      - Mode 5: Full EEC - like Mode 4, but with Enhanced Error Correction (safer, but less useable data)

);

///////////////////////////////////////////////////////////////////////////////
/// Gets current encoding mode for Maxicode.
/// Returns currently adjusted value.
/// \see BCSet_Maxi_Mode()
/// \retval 4               This is the default
/// \retval >0              Otherwise
/// \ingroup Maxi
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGet_Maxi_Mode
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Activates Maxicode "Structured Append" feature.
/// Maxicode allows user data to be spread across several symbols. 
/// This might be done if the data is too large to fit into a single symbol or 
/// for reasons of appearance and geometry.
/// The so called "Structured Append" mode encodes additional control information 
/// that enables the reading device to reconstruct the data of all symbols in the correct order.
/// \n
/// This functions sets the total number of symbols and the index 
/// of the actual MaxiCode symbol within the symbol chain. 
/// Depending on this index, the data will be reconstructed by the scanner during 
/// the reading process. The scanner returns the data of all symbols in the correct 
/// order at once.
/// \see BCGet_Maxi_Append()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Maxi
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_Maxi_Append
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LONG                        nSum,       ///< IN : Total number of symbols [2..8]     
LONG                        nIndex      ///< IN : Index of current symbol [1..8]       
);

///////////////////////////////////////////////////////////////////////////////
/// Gets total number of symbols in "Structured Append" mode of Maxicode.
/// Returns currently adjusted value 
/// \see BCSet_Maxi_Append()
/// \retval -1              No value set. This is the default
/// \retval [2..8]          Otherwise
/// \ingroup Maxi
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGet_Maxi_AppendSum
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Gets index of current symbol in "Structured Append" mode of Maxicode.
/// Returns currently adjusted value.
/// \see BCSet_Maxi_Append()
/// \retval -1      No value set. This is the default
/// \retval [1..8]  Otherwise
/// \ingroup Maxi
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGet_Maxi_AppendIndex
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Specifies the undercut value of Maxicode. 
/// This value influences the diameter of the bar-code items (which are small hexagons in case of Maxicode). 
/// Modify this value, if reading problems with the used output medium occur.
/// \note Default value: -1 (75% undercut)
/// \see BCGet_Maxi_UnderCut()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Maxi
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_Maxi_UnderCut
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LONG                        nUndercut   ///< IN : undercut in percent [1..100] 
);

///////////////////////////////////////////////////////////////////////////////
/// Gets current undercut value of Maxicode. 
/// Returns currently adjusted value.
/// \see BCSet_Maxi_UnderCut()
/// \retval -1          No value set. This is the default and corresponds to 75% undercut.
/// \retval [1..100]    Otherwise
/// \ingroup Maxi
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGet_Maxi_UnderCut
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Activates the usage of the "Preamble" in Maxicode.
/// Specifies whether preamble functionality ("[)>..." will be encoded in the symbol header) should be activated.
/// This is relevant in particular Open System Standards only. Refer to the 
/// additional document Bar-Code Reference (chapter setting SCM parameters).
/// \see BCGet_Maxi_UsePreamble()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Maxi
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_Maxi_UsePreamble
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
BOOL                        bUse,       ///< IN : Use preamble ("[)>...")
                                        ///<        
                                        ///<     - true: Activate preamble
                                        ///<     - false: Preamble is not used
LPCSTR                      szDate      ///< IN : Specifies the value for the year ["00"..."99"] (the last two digits - the century - are used). 
                                        ///< This date will be inserted automatically into the data stream on a pre-defined place (before the encoded data). 
                                        ///< The parameter bUse must be set to true!
);

///////////////////////////////////////////////////////////////////////////////
/// Determines whether the usage of the "Preamble" is activated. 
/// Returns currently adjusted value.
/// \see BCGSt_Maxi_UsePreamble()
/// \retval true            Preamble is activated
/// \retval false           Preamble is not activated. This is the default
/// \ingroup Maxi
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
BOOL        TECIT_STDCALL   BCGet_Maxi_UsePreamble
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Returns the curent date encoded in the Maxicode preamble. 
/// Returns currently adjusted value.
/// \see BCSet_Maxi_UsePreamble()
/// \retval NULL            No value set. This is the default
/// \retval ["00"..."99"]   Otherwise
/// \ingroup Maxi
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LPCSTR      TECIT_STDCALL   BCGet_Maxi_PreambleDate
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Set Maxicode structured carrier message (SCM).
/// For a detailed description refer to the additional document Bar-Code Reference (chapter setting SCM parameters).
/// \see BCGet_Maxi_SCMServClass(), BCGet_Maxi_SCMCountryCode(), BCGet_Maxi_SCMPostalCode()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Maxi
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_Maxi_SCM
(
t_BarCode*  const           pBarCode,       ///< IN : Pointer to bar-code structure
LPCSTR                      szServiceClass, ///< IN : Service class ["000"..."999"]. Specify the Service Class. Used in the modes 2 and 3 (SCM). 
LPCSTR                      szCountryCode,  ///< IN : Country Code ["000"..."999"]. Used in the modes 2 and 3 (SCM). 
LPCSTR                      szPostalCode    ///< IN : The Postal Code - used in the modes 2 and 3 (SCM - " Structured Carrier Message"). String with altogether 9 digits (or other characters), depends on MAXI_Mode.
);

///////////////////////////////////////////////////////////////////////////////
/// Gets service class of Maxicode Structured Carrier Message (SCM). 
/// Returns currently adjusted value.
/// \see BCSet_Maxi_SCM()
/// \retval NULL            No value set. This is the default
/// \retval ["000"..."999"] Otherwise
/// \ingroup Maxi
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LPCSTR      TECIT_STDCALL   BCGet_Maxi_SCMServClass
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Gets country code of Maxicode Structured Carrier Message (SCM). 
/// Returns currently adjusted value.
/// \see BCSet_Maxi_SCM()
/// \retval NULL            No value set. This is the default
/// \retval ["000"..."999"] Otherwise
/// \ingroup Maxi
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LPCSTR      TECIT_STDCALL   BCGet_Maxi_SCMCountryCode
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Gets postal code of Maxicode Structured Carrier Message (SCM). 
/// Returns currently adjusted value.
/// \see BCSet_Maxi_SCM()
/// \retval NULL            No value set. This is the default
/// \retval LPCSTR          See BCSet_Maxi_SCM()
/// \ingroup Maxi
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LPCSTR      TECIT_STDCALL   BCGet_Maxi_SCMPostalCode
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets Data Matrix symbol size.
/// Specifies the size of the symbol. The size is given in rows and columns and 
/// can be between 10 x 10 and 144 x 144 for squares or 8 x 18 and 16 x 48 for rectangles.
/// If no fixed size is selected TBarCode computes the minimal required size of 
/// the symbol automatically. 
/// \see BCGet_DM_Size()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup DM
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_DM_Size
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
e_DMSizes                   eSize       ///< IN : Bar-code size enumerator
);

///////////////////////////////////////////////////////////////////////////////
/// Gets currently adjusted Data Matrix symbol size.
/// Returns currently adjusted value.
/// \see BCSet_DM_Size()
/// \retval eDMSz_Default   No value set. This is the default (TBarCode determines the optimal smbol size automatically)
/// \retval e_DMSizes       Otherwise
/// \ingroup DM
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
e_DMSizes   TECIT_STDCALL   BCGet_DM_Size
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Switches between square or rectangular Data Matrix symbols.
/// Per default TBarCode computes square Data Matrix symbols. Change this behavior with this function. 
/// \see BCGet_DM_Rectangular()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup DM
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_DM_Rectangular
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
BOOL                        bRect       ///< IN : Rectangular symbols preferred
                                        ///<
                                        ///< - true: Generate rectangular symbols 
                                        ///< - false: Generate square symbols (this is the default)
);

///////////////////////////////////////////////////////////////////////////////
/// Gets if rectangular Data Matrix sizes are preferred.
/// Returns currently adjusted value.
/// \see BCSet_DM_Rectangular()
/// \retval false           Square sizes are preferred. This is the default
/// \retval true            Rectangular sizes are preferred.
/// \ingroup DM
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
BOOL        TECIT_STDCALL   BCGet_DM_Rectangular
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Specifies Data Matrix encoding format.
/// Specifies the generated code format. Per default TBarCode uses the default encoding scheme. 
/// \see BCGet_DM_Format()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup DM
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_DM_Format
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
e_DMFormat                  eFormat     ///< IN : Data Matrix format           
);

///////////////////////////////////////////////////////////////////////////////
/// Gets the current Data Matrix Encoding Format.
/// Returns currently adjusted value 
/// \see BCSet_DM_Format()
/// \retval eDMPr_Default   This is the default
/// \retval e_DMFormat      Otherwise
/// \ingroup DM
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
e_DMFormat  TECIT_STDCALL   BCGet_DM_Format
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Activates Data Matrix "Structured Append" mode.
/// Data Matrix allows user data to be spread across several symbols. 
/// This might be done if the data is too large to fit into a single symbol or 
/// for reasons of appearance and geometry. The so called "Structured Append" mode 
/// encodes additional control information to enable the reading device to reconstruct 
/// the data of all symbols in the correct order.
/// This function sets the total number of symbols and the index 
/// of the actual Data Matrix symbol within the symbol chain. 
/// Depending on this index, the data will be reconstructed by the scanner during 
/// the reading process. The scanner returns the data of all symbols in the correct 
/// order at once. Default: no Structured Append is used.
/// \\note All symbols within a symbol chain must be identified by a unique File-ID.
/// \see BCGet_DM_AppendSum(), BCGet_DM_AppendIndex(),  BCGet_DM_AppendFileID()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup DM
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_DM_Append
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LONG                        nSum,       ///< IN : Number of symbols [2..16] (reset to default/disable = -1)   
LONG                        nIndex,     ///< IN : Index of symbol [1..16]
LONG                        nFileID     ///< IN : File ID (must be the same in all symbols)
);

///////////////////////////////////////////////////////////////////////////////
/// Gets the adjusted total number of symbols in Data Matrix Structured Append mode.
/// Returns currently adjusted value 
/// \see BCSet_DM_Append()
/// \retval -1              No Structured Append. This is the default
/// \retval [2..16]         Otherwise
/// \ingroup DM
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGet_DM_AppendSum
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Gets the current index of the symbol in Data Matrix Structured Append mode.
/// Returns currently adjusted value.
/// \see BCSet_DM_Append()
/// \retval -1              No Structured Append. This is the default
/// \retval [1..16]         Otherwise
/// \ingroup DM
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGet_DM_AppendIndex
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Gets the adjusted File-ID in Data Matrix Structured Append mode.
/// Returns currently adjusted value.
/// \see BCSet_DM_Append()
/// \retval -1              No Structured Append. This is the default
/// \retval LONG            Otherwise
/// \ingroup DM
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGet_DM_AppendFileID
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Specifies the symbol version (the symbol size).
/// Specifies the size of the symbol. QR-code supports a number of different symbol sizes 
/// - these sizes are called "versions" (see #e_QRVersion). If no fixed size is selected TBarCode 
/// computes the minimal required size of the symbol automatically. 
/// \see BCGet_QR_Version()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup QR
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_QR_Version
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
e_QRVersion                 eVersion    ///< IN : Symbol version (size)        
);

///////////////////////////////////////////////////////////////////////////////
/// Gets the current symbol version (the symbol size).
/// Returns currently adjusted value.
/// \see BCSet_QR_Version()
/// \retval eQRVers_Default No value set. This is the default and the minimal symbol size will be computed automatically
/// \retval e_QRVersion     Otherwise
/// \ingroup QR
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
e_QRVersion TECIT_STDCALL   BCGet_QR_Version
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Specifies QR-Code encoding format.
/// Specifies the generated code format. Per default TBarCode uses the default 
/// encoding scheme without a special header. 
/// \see BCGet_QR_Format()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup QR
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_QR_Format
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
e_QRFormat                  eFormat     ///< IN : QR-Code format  
);

///////////////////////////////////////////////////////////////////////////////
/// Gets the current encoding format.
/// Returns currently adjusted value.
/// \see BCSet_QR_Format()
/// \retval eQRPr_Default   No value set. This is the default
/// \retval e_QRFormat      Otherwise
/// \ingroup QR
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
e_QRFormat  TECIT_STDCALL   BCGet_QR_Format
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Set QR-Code format Application Indicator (used with Industry format).
/// Is used only in connection with Industry-Format. The Application Indicator determines, to which industry format the input stream corresponds. 
/// \see BCGet_QR_FmtAppIndicator()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup QR
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_QR_FmtAppIndicator
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LPCSTR                      szIndicator ///< IN : Format application indicator ["0"..."99"] or [a-z, A-Z]
);

///////////////////////////////////////////////////////////////////////////////
/// Gets current QR-Code Format application indicator (used with Industry format).
/// Returns currently adjusted value.
/// \see BCSet_QR_FmtAppIndicator()
/// \retval NULL            No value set. This is the default
/// \retval ["0"..."99"],[a-z, A-Z]         Otherwise
/// \ingroup QR
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LPCSTR      TECIT_STDCALL   BCGet_QR_FmtAppIndicator
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets QR-Code error correction level (ECL).
/// Sets QR-Code error correction level (ECL). If not set, TBarCode uses medium error correction level per default.
/// \see BCGet_QR_ECLevel()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup QR
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_QR_ECLevel
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
e_QRECLevel                 eECLevel    ///< IN : Error correction level       
);

///////////////////////////////////////////////////////////////////////////////
/// Gets the current QR-Code error correction level (ECL).
/// Returns currently adjusted value.
/// \see BCSet_QR_ECLevel()
/// \retval eQREC_Medium    This is the default
/// \retval e_QRECLevel     Otherwise
/// \ingroup QR
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
e_QRECLevel TECIT_STDCALL   BCGet_QR_ECLevel
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets QR-Code mask pattern (0-7).
/// Spcifies the so-called "mask" that is applied to the QR-Code to achieve the highest possible readability. 
/// TBarCode computes the optimal mask automatically. This is very time consuming - if the encoding process must be optimized set a pre-defined mask.
/// \see BCGet_QR_Mask()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup QR
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_QR_Mask
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
e_QRMask                    eMask       ///< IN : Mask pattern
);

///////////////////////////////////////////////////////////////////////////////
/// Gets the current QR-Code mask pattern (0-7).
/// Returns currently adjusted value
/// \see BCSet_QR_Mask()
/// \retval eQRMsk_Default  No value set. This is the default
/// \retval e_QRMask        Otherwise
/// \ingroup QR
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
e_QRMask    TECIT_STDCALL   BCGet_QR_Mask
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Enables QR-Code "Compact Kanji" option. 
/// Enables the compaction of Kanji characters into 12-bit values. 
/// Precondition: The Kanji-characters must be supplied as MultiByte character set Shift JIS X 0208.
/// \see BCGet_QR_CompactKanji(), BCSetTextW()
/// \note Do not use this option for pure binary data or ASCII characters. 
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup QR
/////////////////////////////////////////////////////////////////////////////// 
TECIT_DLLSPEC   
ERRCODE TECIT_STDCALL       BCSet_QR_CompactKanji
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
BOOL                        bCompact    ///< IN : Compact Kanji option
                                        ///<
                                        ///< - true: Compact Kanji 
                                        ///< - false: Do not compact Kanji (this is the default)
);

///////////////////////////////////////////////////////////////////////////////
/// Gets the current state of the QR-Code "Compact Kanji" option. 
/// Returns currently adjusted value 
/// \see BCSet_QR_CompactKanji()
/// \retval false           No value set. This is the default
/// \retval true            Otherwise
/// \ingroup QR
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
BOOL        TECIT_STDCALL   BCGet_QR_CompactKanji
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Activates QR-Code "Structured Append" feature.
/// QR-Code allows user data to be spread across several symbols. 
/// This might be done if the data is too large to fit into a single symbol or 
/// for reasons of appearance and geometry. The so called "Structured Append" mode 
/// encodes additional control information to enable the reading device to reconstruct 
/// the data of all symbols in the correct order. Default: Structured Append is disabled.
/// \n
/// This function enables Structured Append and sets the total number of symbols and the index 
/// of the actual QR-Code symbol within the symbol chain. 
/// Depending on this index, the data will be reconstructed by the scanner during 
/// the reading process. The scanner returns the data of all symbols in the correct 
/// order at once.\n
/// All symbols within a symbol chain must be identified by a Parity. This parity is computed with BCCalcStructApp_Parity().
/// \see BCGet_QR_AppendSum(), BCGet_QR_AppendIndex(), BCGet_QR_AppendParity()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup QR
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_QR_Append
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LONG                        nSum,       ///< IN : Total number of symbols [2..16]   (reset to default/disable = -1) 
LONG                        nIndex,     ///< IN : Index of current symbol [1..16]      
BYTE                        bParity     ///< IN : Parity byte (must be the same in all symbols)
);

///////////////////////////////////////////////////////////////////////////////
/// Gets the total number of symbol when using QR-Code "Structured Append". 
/// Returns currently adjusted value.
/// \see BCSet_QR_Append()
/// \retval -1              No value set. This is the default
/// \retval [2..16]         Otherwise
/// \ingroup QR
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGet_QR_AppendSum
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure

);

///////////////////////////////////////////////////////////////////////////////
/// Gets the structured append index of the symbol when using QR-Code "Structured Append". 
/// Returns currently adjusted value.
/// \see BCSet_QR_Append()
/// \retval -1              No value set. This is the default
/// \retval [1..16]         Otherwise
/// \ingroup QR
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGet_QR_AppendIndex
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Gets the structured append parity when using QR-Code "Structured Append". 
/// Returns currently adjusted value.
/// \see BCSet_QR_Append()
/// \retval 0               No value set. This is the default
/// \retval [0..255]        Otherwise
/// \ingroup QR
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
BYTE        TECIT_STDCALL   BCGet_QR_AppendParity
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Adjusts the number of Codablock-F rows.
/// Specifies the number of rows that should be used for the Codablock-F symbol.
/// If this value is not set explicitly, TBarCode computes the number of rows automatically (default).
/// \see BCGet_CBF_Rows()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup CBF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_CBF_Rows
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LONG                        nRows       ///< IN : Number of rows [2..44]  (-1 ... reset to default)     
);

///////////////////////////////////////////////////////////////////////////////
/// Gets the adjusted number of Codablock-F rows.
/// Returns currently adjusted value. 
/// \see BCSet_CBF_Rows()
/// \retval -1              No value set. This is the default
/// \retval [2..44]         Otherwise
/// \ingroup CBF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGet_CBF_Rows
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Adjusts the number of Codablock-F columns.
/// Specifies the number of columns that should be used for the Codablock-F symbol.
/// If this value is not set explicitly, TBarCode computes the number of columns automatically (default).
/// \see BCGet_CBF_Columns()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup CBF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_CBF_Columns
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LONG                        nColumns    ///< IN : Number of columns [4..62]  (-1 ... reset to default)  
);

///////////////////////////////////////////////////////////////////////////////
/// Gets the number of adjusted Codablock-F columns.
/// Returns currently adjusted value.
/// \see BCSet_CBF_Columns()
/// \retval -1              No value set. This is the default
/// \retval [4..62]         Otherwise
/// \ingroup CBF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGet_CBF_Columns
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets the row height for Codablock-F.
/// Specifies the height of an individual row in 1/1000 mm.
/// If this value is not set explicitly (=default), the height is calculated according to the 
/// bounding rectangle when drawing (see BCDraw()). If set, ensure that the bounding 
/// rectangle is big enough to avoid clipping.
/// \see BCGet_CBF_RowHeight()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup CBF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_CBF_RowHeight
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LONG                        nHeight     ///< IN : Row height [1/1000 mm] (-1 ... reset to default)      
);

///////////////////////////////////////////////////////////////////////////////
/// Gets the adjusted row height for Codablock-F.
/// Returns currently adjusted value.
/// \see BCSet_CBF_RowHeight()
/// \retval -1              No value set. This is the default
/// \retval LONG            Row height [1/1000 mm]     
/// \ingroup CBF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGet_CBF_RowHeight
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets the height of the Codablock-F row-separator.
/// Specifies the height of the row-separator in 1/1000 mm. 
/// If this value is not set (=default), the height of the separator row is calculated 
/// automatically (according to the bounding rectangle). 
/// If set, ensure that the bounding rectangle is big enough to avoid clipping.
/// \see BCGet_CBF_RowSeparatorHeight()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup CBF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_CBF_RowSeparatorHeight
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
LONG                        nHeight     ///< IN : Row separator height [1/1000 mm] (-1 ... reset to default)      
);

///////////////////////////////////////////////////////////////////////////////
/// Gets the currently adjusted row separator height for Codablock-F.
/// Returns currently adjusted value.
/// \see BCSet_CBF_RowSeparatorHeight()
/// \retval -1              No value set. This is the default
/// \retval LONG            Row separator height [1/1000 mm]     
/// \ingroup CBF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGet_CBF_RowSeparatorHeight
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets Codablock-F code format.
/// Specifies the encoding format for Codablock-F. Selects UCC/EAN or the default encoding format.
/// \see BCGet_CBF_Format()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup CBF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_CBF_Format
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
e_CBFFormat                 eFormat     ///< IN : Codablock F format           
);

///////////////////////////////////////////////////////////////////////////////
/// Gets the adjusted Codablock-F code format.
/// Returns currently adjusted value.
/// \see BCSet_CBF_Format()
/// \retval eCBFPr_Default  No value set. This is the default
/// \retval e_CBFFormat     Otherwise   
/// \ingroup CBF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
e_CBFFormat TECIT_STDCALL   BCGet_CBF_Format
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Activates the substitution of font names for EPS.
/// Substitutes Windows font-names with Postscript-compatible fonts in functions
/// BCSaveImage() and BCSameImageExt() when using EPS Vector format.
/// \see BCGet_EPS_SubstwDeviceFonts(), BCSaveImage(),BCSaveImageExt()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Save
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_EPS_SubstwDeviceFonts
(
t_BarCode*  const           pBarCode,       ///< IN : Pointer to bar-code structure        
BOOL                        bSubwDevFnts    ///< IN : Substitute with Postscript fonts 
                                            ///<
                                            ///< - true: Subsitute font-names enabled
                                            ///< - false: Do not subsitute font-names (this is the default)
);

///////////////////////////////////////////////////////////////////////////////
/// Gets current setting for substitute font names for EPS.
/// Returns currently adjusted value.
/// \see BCSet_EPS_SubstwDeviceFonts()
/// \retval false           No value set. This is the default
/// \retval true            Otherwise   
/// \ingroup Save
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
BOOL  TECIT_STDCALL         BCGet_EPS_SubstwDeviceFonts
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets data segments per Row (RSS Expanded Stacked only) to a fixed value.
/// The value of nSegmPerRow specifies how many data words (segments) are encoded in one data row of the symbol.
/// Values in the range from 2 to 22 are allowed. Data words are encoded in pairs, so only even numbers are valid. Wrong values are autocorrected by TBarCode.
/// If this value is not set (default), the number of data segments per row is 4.
/// \see BCGet_RSS_SegmPerRow()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup RSS
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_RSS_SegmPerRow
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure     
LONG                        nSegmPerRow ///< IN : Number of segments per row [2..22] (-1 ... reset to default)
);

///////////////////////////////////////////////////////////////////////////////
/// Gets currently adjusted data segments per row (RSS Expanded Stacked only).
/// Returns currently adjusted value.
/// \see BCSet_RSS_SegmPerRow()
/// \retval -1              No value set. This is the default
/// \retval [2..22]         Otherwise   
/// \ingroup RSS
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG    TECIT_STDCALL       BCGet_RSS_SegmPerRow
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure     
);

///////////////////////////////////////////////////////////////////////////////
/// Sets Micro PDF encoding mode.
/// This option adjusts how data is encoded as MicroPDF417. 
/// In most cases the Default or the Binary mode is the best choice. 
/// Often the scanner hardware does not support all modes listed here - 
/// check with your reading device first.
/// If not set explicitly, TBarCode analyzes input data. Text, numeric or binary compaction mode will be switched automatically in order to procude the smallest possible symbol.
/// \see BCGet_MPDF417_Mode()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup PDF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_MPDF417_Mode
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
e_MPDFMode                  eMode       ///< IN : Encoding mode                         
);

///////////////////////////////////////////////////////////////////////////////
/// Gets Micro PDF encoding mode.
/// Returns currently adjusted value.
/// \see BCSet_MPDF417_Mode()
/// \retval eMPDFPr_Default     No value set. This is the default
/// \retval e_MPDFMode          Otherwise   
/// \ingroup PDF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
e_MPDFMode  TECIT_STDCALL   BCGet_MPDF417_Mode
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Sets Micro PDF Version (symbol size).
/// The MicroPDF Version adjusts the number of data-columns and data-rows of the symbol; therefore it specifies the size of the symbol. 
/// You can specify versions between 1x11 to 4x44 (horizontal data-columns x vertical data-rows). 
/// If not set explicitly, TBarCode generates the smallest possible symbol by analyzing the input data and choosing the suitable version automatically.
/// \see BCGet_MPDF417_Version()
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup PDF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCSet_MPDF417_Version
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
e_MPDFVers                  eVersion    ///< IN : version (size)               
);

///////////////////////////////////////////////////////////////////////////////
/// Gets Micro PDF Version (symbol size).
/// Returns currently adjusted value.
/// \see BCSet_MPDF417_Version()
/// \retval eMPDFVer_Default    No value set. This is the default
/// \retval e_MPDFVers          Otherwise   
/// \ingroup PDF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
e_MPDFVers  TECIT_STDCALL   BCGet_MPDF417_Version
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

/*-----------------------------------------------------------------------------

    M E T H O D S

-----------------------------------------------------------------------------*/

////////////////////////////////////////////////////////////////////////////////
/// License TBarCode.
/// Licenses the library with the license key provided by TEC-IT. All demo-mode restrictions are removed. 
/// Licensing must take place before you draw a bar-code or generate a bar-code image file. After licensing the library will stay in licensed mode until it is unloaded from memory. Call this function and pass in the license key you have got after purchasing your license. 
/// You receive the license key from TEC-IT Datenverarbeitung GmbH (you can order through http://www.tec-it.com/order).
/// The license kind, the number of licenses and the licensee string have to be passed in exactly as given, they are checked against the license key.
/// \n\n
/// \note For Windows only (TBarCode DLL):
/// - If the license key starts with "Mem: xxxxxxxx" the product is licensed until TBarCode will be unloaded from memory.
/// - If the license key received by TEC-IT looks like "HKCU:xxxxxxxx" the product is licensed in the section "HKEY Current User" of the Windows registry.
/// - If the license key received by TEC-IT looks like "xxxxxxxx" or "HKLM:xxxxxxxx" the product is licensed within the section "HK Local Machine" of the Windows Registry (this is the default).
/// 
/// \note Alternative licensing method: For TBarCode DLL TEC-IT provides the possibility to license the product via an .ini-file (please contact TEC-IT for details).
/// 
/// \retval #ERRCODE    Returns always ErrOk (0) - even if license key is invalid   
/// \ingroup General
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCLicenseMe
(
LPCSTR                      lpszLicensee,   ///< IN : String containing the name of the Licensee. Provided by TEC-IT after ordering.
e_licKind                   eKindOfLicense, ///< IN : The type of the license. Provided by TEC-IT after ordering.
DWORD                       dwNoOfLicenses, ///< IN : The number of available licenses. Provided by TEC-IT after ordering.
LPCSTR                      lpszKey,        ///< IN : String containing the license key Provided by TEC-IT after ordering.
e_licProduct                eProductID      ///< IN : The type of the licensed product variant (1D or 2D). The Product ID indicates which bar-code types will be licensed. One-dimensional (1D or linear bar-codes)  (1D = Code128, UPC, EAN, Code39, ...) or two-dimensional (2D) bar-codes (PDF417, MaxiCode, Data Matrix, ...).
);

////////////////////////////////////////////////////////////////////////////////
/// Returns the default print-ratio string of the bar-code.
/// Returns the default print-ratio of the selected bar-code type as string.
/// The ratio string looks like "1:3:1:3" where the single values separated by colons corresponds to the ratio-values of the bars or spaces. 
/// The format of the ratio-string matches the format of the ratio-hint (see BCGetRatioHint()). 
/// This default value is used if no other print-ratio was selected.
/// \see BCSetRatio(), BCGetRatioHint()
/// \retval LPCSTR          Bar-code symbology depending string in the format "1:2:...:1:2"
/// \ingroup Ratio
////////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LPCSTR      TECIT_STDCALL   BCGetRatioString
(
e_BarCType                  eType       ///< IN : Bar-Code type
);

////////////////////////////////////////////////////////////////////////////////
/// Returns the format hint for the print-ratio.
/// Return the format of the ratio-string (to be used only as hint for users or developers). 
/// This hint serves as template for your own print-ratio strings passed to BSSetRatio(). The value depends on the selected bar-code symbology. 
/// Learn more about it in the Bar-Code Reference. 
/// \see BCSetRatio(), BCGetRatio(), BCGetRatioString()
/// \retval LPCSTR      Bar-code symbology depending string in the format "1B:2B:...:1S:2S"
/// \ingroup Ratio
////////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LPCSTR      TECIT_STDCALL   BCGetRatioHint
(
e_BarCType                  eType       ///< IN : Bar-Code type                
);

////////////////////////////////////////////////////////////////////////////////
/// Returns the number of characters for a specified bar-code.
/// Returns the exact number of characters that can be encoded with the specified bar-code symbology. 
/// Returns zero if there is no specified length or an unknown bar-code type was passed.
/// \retval >0  The number of expected input characters. 
/// \retval 0   Number of input characters is unknown for this bar-code. 
/// \ingroup Valid
////////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGetMaxLenOfData
(
e_BarCType                  eType       ///< IN : Bar-Code type                
);

///////////////////////////////////////////////////////////////////////////////
/// Checks bar-code input data for validity.
/// The bar code data is validated to be encoded with the selected symbology.
/// Adjust all bar code parameters before you call this function. 
/// If the input data is invalid (a non-zero error code was returned), you can correct the bar code data and try again.
/// If the check was successful, do not change bar-code parameters or input data anymore (before you create a bar code).
/// \note This function call is optional - if used must be called before BCCreate().
/// \note Escape sequences in the bar code data (if enabled) are NOT translated during this check.
/// \see BCSetText(), BCGet_InvalidDataPos(), BCSetTranslateEsc()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Valid
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCCheck
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Calculates check-digit(s).
/// Calculates the check-digit(s) depending on all bar-code parameters previously set.
/// The calculated check digits will be added to the bar code data automatically. 
/// You can retrieve the calculated check sum with BCGetCheckDigits(). 
/// Do not change bar-code parameters or input data after this call (if you want to generate a bar code).
/// \note This function call is optional - if used, must be called before BCCreate()!
/// \note Symbology internal check sums (e.g. Mod-103 used with Code128) are not calculated with this function. Such internal check sums are generated during BCCreate() without the need of user interaction.
/// \see  BCSetCDMethod(), BCGetCheckDigits()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred. 
/// \ingroup Check
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCCalcCD
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Creates the internal bar-code representation.
/// Creates the internal bar-code representation depending on all bar-code parameters previously set. 
/// After this call the bar-code is ready for drawing or saving (e.g. with BCDraw()). Do not change bar-code parameters or input data after this call.
/// \see BCDraw(), BCSaveImage()
/// \note   This function call is a must!
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred. 
/// \ingroup General
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCCreate
(
t_BarCode*  const           pBarCode    ///< IN : Pointer to bar-code structure
);

#ifdef TBARCODE_DLL
///////////////////////////////////////////////////////////////////////////////
/// Draws bar-code onto the given device context (Windows only).
/// Draws the bar-code onto the given device context. The coordinates of the 
/// bounding rectangle defines the bar-code dimensions. 
/// The coordinates passed in pRect are interpreted in the current mapping mode of the device context. 
/// No special coordinate mapping is performed.
/// \see BCDrawCB() for custom drawing functionality.
/// \note WINDOWS only (TBarCode DLL API)
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred. 
/// \ingroup Draw
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCDraw
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
HDC                         hDC,        ///< IN : Device context handle        
RECT*                       pRect       ///< IN : Bounding rectangle           
);
#endif // TBARCODE_DLL

///////////////////////////////////////////////////////////////////////////////
/// Callback version of bar-code draw function.
/// Call this function instead of BCDraw() if you want to use your own drawing routines 
/// (e.g. for generating a bar-code on special devices or in special output formats). 
/// - fn_DrawBar is used for drawing the bars
/// - fn_DrawText is used for drawing the human readable text. Pass a NULL value if not required. 
/// \note BCDrawCB() can be used only with a developer license. Sample code is available on request: support@tec-it.com
/// \note Call-backs are disabled in the demo-version of TBarCode. If you need to try it please contact TEC-IT for a temporary license key.
/// \note WINDOWS only (TBarCode DLL API)
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred. 
/// \ingroup Callback
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE     TECIT_STDCALL   BCDrawCB
(
t_BarCode*  const           pBarCode,   ///< IN : Pointer to bar-code structure
HDC                         hDC,        ///< IN : Device context handle        
RECT*                       pRect,      ///< IN : Bounding rectangle           
fn_DrawBar                  fnDrawBar,  ///< IN : Callback function pointer for drawing the bars      
fn_DrawText                 fnDrawText, ///< IN : Callback function pointer for drawing the human readable text. May be NULL if not required.
LPVOID                      pData       ///< IN : Custom data to pass to callback functions               
);

///////////////////////////////////////////////////////////////////////////////
/// Returns implemented bar-code symbologies
/// Returns string-array of implemented bar-codes. Use this function in connection with BCGetBCCount().
/// \see BCGetBCCount()
/// \retval LPCSTR* String-array of supported bar-code symbologies. 
/// \ingroup Impl
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LPCSTR* TECIT_STDCALL       BCGetBCList
(
);

///////////////////////////////////////////////////////////////////////////////
/// Returns number of implemented bar-codes.
/// Returns number of implemented bar-codes. The return value specifies the size of the array returned by BCGetBCList().
/// \see BCGetBCList()
/// \retval LONG Number of supported bar-code symbologies
/// \ingroup Impl
/////////////////////////////////////////////////////////////////////////////// 
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGetBCCount
(
);

///////////////////////////////////////////////////////////////////////////////
/// Returns the implemented check-digit methods for a bar-code symbology.
/// Returns an array of implemented check-digit methods for the specified bar-code symbology. 
/// \retval e_CDMethod* Array of check-digit method enumerators. The array is terminated with -1 (maximum array size is 5).
/// \ingroup Impl
/////////////////////////////////////////////////////////////////////////////// 
TECIT_DLLSPEC   
e_CDMethod* TECIT_STDCALL   BCGetCDListByType
(
e_BarCType  eBCType
);

///////////////////////////////////////////////////////////////////////////////
/// Returns name of check-digit method.
/// Returns string description of the check-digit method specified.
/// \retval LPCSTR  String describing the check-digit method specified
/// \ingroup Impl
/////////////////////////////////////////////////////////////////////////////// 
TECIT_DLLSPEC   
LPCSTR  TECIT_STDCALL       BCGetNameFromEnum
(
e_CDMethod                  eCDMethod   ///< IN: check-digit method
);

///////////////////////////////////////////////////////////////////////////////
/// Returns the implemented check-digit methods.
/// Returns array of implemented check-digit methods. Use this function in connection with BCGetCDCount().
/// \see BCGetCDCount()
/// \retval LPCSTR* String-array of implemented check-digit methods. 
/// \ingroup Impl
/////////////////////////////////////////////////////////////////////////////// 
TECIT_DLLSPEC   
LPCSTR* TECIT_STDCALL       BCGetCDList
(
);

///////////////////////////////////////////////////////////////////////////////
/// Returns number of implemented check-digit methods.
/// Returns the number of implemented check-digit methods. Use this function in connection with BCGetCDList().
/// \see BCGetCDList()
/// \retval LONG Number of supported check-digit methods
/// \ingroup Impl
/////////////////////////////////////////////////////////////////////////////// 
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGetCDCount
(
);

///////////////////////////////////////////////////////////////////////////////
/// Returns implemented Data Matrix symbol sizes.
/// Returns all possible Data Matrix symbol-sizes in an array.
/// \see BCGetDataMatrixSizesCount()
/// \retval LPCSTR* String array (size is available via BCGetDataMatrixSizesCount())
/// \ingroup Impl
/////////////////////////////////////////////////////////////////////////////// 
TECIT_DLLSPEC   
LPCSTR*     TECIT_STDCALL   BCGetDataMatrixSizes
(
);

///////////////////////////////////////////////////////////////////////////////
/// Returns the number of supported Data Matrix symbol-sizes.
/// Returns the number of possible symbol sizes for Data Matrix.
/// \see BCGetDataMatrixSizes()
/// \retval LONG    Number of supported Data Matrix symbol sizes
/// \ingroup Impl
/////////////////////////////////////////////////////////////////////////////// 
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGetDataMatrixSizesCount
(
);

///////////////////////////////////////////////////////////////////////////////
/// Returns implemented QR-Code versions.
/// Returns all possible QR-Code versions (symbol sizes) in an array.
/// \see BCGetQRCodeVersionCount()
/// \retval LPCSTR* String array (size is available via BCGetQRCodeVersionCount())
/// \ingroup Impl
/////////////////////////////////////////////////////////////////////////////// 
TECIT_DLLSPEC   
LPCSTR*     TECIT_STDCALL   BCGetQRCodeVersions
(
);

///////////////////////////////////////////////////////////////////////////////
/// Returns number of implemented QR-Code versions.
/// Returns the number of possible QR-Code versions
/// \see BCGetQRCodeVersions() 
/// \retval LONG    Number of supported QR-code versions
/// \ingroup Impl
/////////////////////////////////////////////////////////////////////////////// 
TECIT_DLLSPEC   
LONG        TECIT_STDCALL   BCGetQRCodeVersionCount
(
);

///////////////////////////////////////////////////////////////////////////////
/// Returns the height of the bar-code in modules. 
/// The measurement unit used for the return value is the module width (X). 
/// The total symbol height would be the return value of this function * X (X = module width) + height of text area (BCGetTextAreaHeight()).
/// Can be used for BCSaveImage() to optimize the resolution of the resulting image. 
/// \note To be used with 2D symbologies and all composite codes (with a 2D composite component). 
/// Please contact support@tec-it.com if you have to deal with resolution (bitmap) issues. 
/// \see BCGet2D_XCols(), BCGetTextAreaHeight()
/// \retval LONG    Number of vertical modules
/// \ingroup Char
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG    TECIT_STDCALL       BCGet2D_XRows
(
const t_BarCode*  const     pBarCode    ///< IN : Pointer to bar-code structure     
);

///////////////////////////////////////////////////////////////////////////////
/// Returns the width of the bar-code in modules. 
/// The measurement unit used for the return value is the module width (X). 
/// The total symbol width would be the return value of this function * X (X = module width).
/// Can be used for BCSaveImage() to optimize the resolution of the resulting image. 
/// \note To be used with 2D symbologies and all composite codes (with a 2D composite component).
/// \see BCGet2D_XRows(), BCGetTextAreaHeight()
/// \retval LONG    Number of horizontal modules
/// \ingroup Char
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG    TECIT_STDCALL       BCGet2D_XCols
(
const t_BarCode*  const     pBarCode    ///< IN : Pointer to bar-code structure     
);

///////////////////////////////////////////////////////////////////////////////
/// Returns the number of modules in the bar-code.
/// Returns the number of modules for the current bar-code 
/// with respect to encoded data, check-digits, subset and other bar-code parameters. 
/// With 2D symbologies the total number of all modules (in all rows) will be returned.
/// \note To be used with linear symbologies. 
/// \note Call this function after BCCreate()
/// \see BCGet2D_XCols()
/// \retval LONG            Number of modules
/// \ingroup Char
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
DOUBLE  TECIT_STDCALL       BCGetCountModules
(
const t_BarCode* const      pBarCode        ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Returns the number of rows in the bar-code.
/// Returns the number of rows in multi-row symbologies (PDF417, Data Matrix, Codablock-F, QR-Code, MicroPDF417, RSS Stacked versions)
/// \note To be used with the following symbologies: PDF417, Data Matrix, Codablock-F, QR-Code, MicroPDF417
/// \note Call this function after BCCreate()
/// \see BCGet2D_XRows()
/// \retval LONG    Number of rows
/// \ingroup Char
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
DOUBLE  TECIT_STDCALL       BCGetCountRows
(
const t_BarCode* const      pBarCode        ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Returns the module width.
/// Returns the computed module width for a given device context with respect 
/// to encoded data, check-digits, subset and other bar-code parameters. 
/// You can specify the unit, which should be used for the return value.
/// \note In TBarCode/X (UNIX) the parameter hDC is ignored.\n
/// The measurement units in TBarCode/X (UNIX) are:
/// - #eMUDefault ... millimeters
/// - #eMUMM ... millimeters
/// - #eMUPixel ... points (= 1/72 inch)
/// \note Call this function after BCCreate()
/// \retval LONG    Module width
/// \ingroup Char
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
DOUBLE  TECIT_STDCALL       BCGetModuleWidth
(
t_BarCode*  const           pBarCode,       ///< IN : Pointer to bar-code structure
LPRECT                      pRect,          ///< IN : Bounding rectangle           
HDC                         hDC,            ///< IN : Device context handle        
e_MUnit                     eUnit           ///< IN : Measurement unit
);

///////////////////////////////////////////////////////////////////////////////
/// Returns the total width of the bar-code symbol.
/// Returns the total bar-code width in the specified measurement unit for a given device context. 
/// You can specify the measurement unit, which should be used for the return value.
/// Use BCGetBarcodeSize() if you also need the height of the symbol.
/// As for the bounding rectangle pass in the same coordinates as you would use for drawing. 
/// Some symbologies have a specific width/height ratio and therefore the bar code size is adapted
/// to fit into the bounding rectangle. If a module width has been set, the bar code
/// width depends on the module width and the number of horizontal modules.
/// \note In TBarCode/X (UNIX) the parameter hDC is ignored.\n
/// The measurement units in TBarCode/X (UNIX) are:
/// - #eMUDefault ... millimeters
/// - #eMUMM ... millimeters
/// - #eMUPixel ... points (= 1/72 inch)
/// \see BCGetBarcodeHeight(), BCGetBarCodeSize(), BCSetModWidth()
/// \note Call this function after BCCreate()
/// \retval LONG    Width of bar-code symbol
/// \ingroup Char
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
DOUBLE  TECIT_STDCALL       BCGetBarcodeWidth
(
t_BarCode*  const           pBarCode,           ///< IN : Pointer to bar-code structure
LPRECT                      pRect,              ///< IN : Bounding rectangle           
HDC                         hDC,                ///< IN : Device context handle        
e_MUnit                     eUnit               ///< IN : Measurement unit
);

///////////////////////////////////////////////////////////////////////////////
/// Returns the height of the bar-code symbol.
/// Returns the total bar-code height in the specified measurement unit. 
/// Use BCGetBarcodeSize() if you also need the width of the symbol.
/// As for the bounding rectangle pass in the same coordinates as you would use for drawing. 
/// Some symbologies have a specific width/height ratio and therefore the bar code size is adapted 
/// to fit into the bounding rectangle.
/// \n
/// Relevant for 2D or Multi-Row Symbologies (e.g. PDF417, Data Matrix, RSS Stacked...): 
/// If a row height has been set, the bar code height depends on the adjusted row height
/// and the number of rows in the symbol. For some symbologies also the module width is relevenat for the symbol height.
/// \note In TBarCode/X (UNIX) the parameter hDC is ignored.\n
/// The measurement units in TBarCode/X (UNIX) are:
/// - #eMUDefault ... millimeters
/// - #eMUMM ... millimeters
/// - #eMUPixel ... points (= 1/72 inch)
/// \see BCGetBarCodeSize(), BCGetBarcodeWidth(), BCSetModWidth(), BCSet_PDF417_RowHeight()
/// \note Windows only (TBarCode DLL API)
/// \note Call this function after BCCreate()
/// \retval LONG    Height of bar-code symbol
/// \ingroup Char
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
DOUBLE  TECIT_STDCALL       BCGetBarcodeHeight
(
t_BarCode* const            pBarCode,           ///< IN : Pointer to bar-code structure
LPRECT                      pRect,              ///< IN : Bounding rectangle           
HDC                         hDC,                ///< IN : Device context handle        
e_MUnit                     eUnit               ///< IN : Measurement unit             
);

///////////////////////////////////////////////////////////////////////////////
/// Computes the bar-code size (recommended method).
/// Computes width and height of bar-code with one call. 
/// You can use this function before you draw the bar-code to ensure that there is enough space available.
/// Call this function after BCCreate() and specify a bounding rectangle (target coordinates, where you would draw the bar-code).
/// This rectangle is relevant if you haven't specified a module width or a row height.
/// As for the bounding rectangle pass in the same coordinates as you would use for drawing. 
/// Some symbologies have a specific width/height ratio and therefore the bar code size is adapted 
/// to fit into the bounding rectangle.
/// \note In TBarCode/X (UNIX) the parameter hDC is ignored.\n
/// The measurement units in TBarCode/X (UNIX) are:
/// - #eMUDefault ... millimeters
/// - #eMUMM ... millimeters
/// - #eMUPixel ... points (= 1/72 inch)
/// \see BCGetBarcodeHeight(), BCGetBarcodeWidth()
/// \note Windows only (TBarCode DLL API)
/// \note Call this function after BCCreate()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred. 
/// \ingroup Char
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE TECIT_STDCALL       BCGetBarCodeSize
(
t_BarCode*  const           pBarCode,           ///< IN : Pointer to bar-code structure
LPRECT                      pRect,              ///< IN : Bounding rectangle           
HDC                         hDC,                ///< IN : Device context handle        
e_MUnit                     eUnit,              ///< IN : Measurement unit              
DOUBLE*                     pdWidth,            ///< IO : Pointer to resulting width  (NULL if not required)
DOUBLE*                     pdHeight            ///< IO : Pointer to resulting height (NULL if not required)
);

///////////////////////////////////////////////////////////////////////////////
/// Returns the height of the human readable text area.
/// Returns the height of the human readable text area in the specified measurement unit.
/// \note In TBarCode/X (UNIX) the parameter hDC is ignored.\n
/// The measurement units in TBarCode/X (UNIX) are:
/// - #eMUDefault ... millimeters
/// - #eMUMM ... millimeters
/// - #eMUPixel ... points (= 1/72 inch)
/// \retval 0 If no text-area used for bar-code.
/// \retval >0 Height of text-area in the specified measurement units. 
/// \ingroup Char
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
DOUBLE  TECIT_STDCALL       BCGetTextAreaHeight
(
t_BarCode* const            pBarCode,           ///< IN : Pointer to bar-code structure       
LPRECT                      pRect,              ///< IN : Bounding rectangle (optional)   
HDC                         hDC,                ///< IN : Device context handle           
e_MUnit                     eUnit               ///< IN : Measurement unit
);

///////////////////////////////////////////////////////////////////////////////
/// Returns number of different bar-widths used by the symbology.
/// Returns number of different bar-widths used for the specified bar-code symbology. 
/// \n Code 2 of 5 Interleaved uses two different bar-widths: the return value is 2.
/// \see BCGetRatioHint(), BCSetRatio(), BCGetRatio(), BCGetCountSpaces()
/// \retval -1              In case of error
/// \retval >0              Otherwise
/// \ingroup Ratio
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG    TECIT_STDCALL       BCGetCountBars
(
e_BarCType                  eBarCType           ///< IN : Bar-code type                 
);

///////////////////////////////////////////////////////////////////////////////
/// Returns number of different space-widths used by the symbology.
/// Returns number of different space-widths for specified bar-code symbology. 
/// \n Code 2 of 5 Interleaved uses two different space-widths: the return value is 2.
/// \see BCGetRatioHint(), BCSetRatio(), BCGetRatio(), BCGetCountBars()
/// \retval -1              In case of error
/// \retval >0              Otherwise
/// \ingroup Ratio
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG    TECIT_STDCALL       BCGetCountSpaces
(
e_BarCType                  eBarCType           ///< IN : Bar-code type                 
);

///////////////////////////////////////////////////////////////////////////////
/// Returns drawing quality estimate of the bar-code (in percent) (Windows only).
/// TBarCode computes the expected bar-code quality depending on the used output resolution.
/// This value is a measure for the bar width aberration created by the output resolution of the device context (and therefore of the device itself).
/// The higher the quality value - the better.
/// \note WINDOWS only (TBarCode DLL API).
/// \retval LONG    Bar-code quality [0 (unreadable)...100 (perfect)]
/// \ingroup Quality
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG    TECIT_STDCALL       BCGetQuality
(
t_BarCode*  const           pBarCode,           ///< IN : Pointer to bar-code structure 
HDC                         hDC,                ///< IN : Device context handle of output device
RECT*                       pRect               ///< IN : Bounding rectangle 
);

///////////////////////////////////////////////////////////////////////////////
/// Gets number of PDF417 code words.
/// Gets number of PDF417 code words. 
/// \note Call after BCCreate()
/// \retval LONG    Number of used PDF417 code words 
/// \ingroup PDF
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LONG    TECIT_STDCALL       BCGet_PDF417_CodeWords
(
t_BarCode*  const           pBarCode            ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Determines if a composite component was created.
/// After BCCreate() you can check if a composite component is present (and therefore is part of the created symbol). 
/// This method is useful if you adjusted a composite component to be created but - depending on missing input data - the composite component may be omitted (only the linear bar code appears). 
/// \note Call after BCCreate()
/// \retval true            A composite component was created
/// \retval false           No composite component was created
/// \ingroup CompSym
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
BOOL    TECIT_STDCALL       BCGet_CompSym_IsCCPresent
(
t_BarCode*  const           pBarCode            ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Check if a composite component is available for the current base symbology.
/// Used with EAN.UCC Composite Symbology. Tells you if a specific 2D composite component (CC-A/B/C) can be combined with the selected base symbology. Adjust the base symbology first with BCSetBCType().
/// \retval true   The specified composite component is available 
/// \retval false  The specified composite component is not available 
/// \ingroup CompSym
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
BOOL    TECIT_STDCALL       BCGet_CompSym_IsCCAvailable
(
t_BarCode*  const           pBarCode,           ///< IN : Pointer to bar-code structure
e_CCType                    eCCType             ///< IN : Composite component type (symbology of composite component)
);

///////////////////////////////////////////////////////////////////////////////
/// Determines the source of the error when creating composite symbologies. 
/// If BCCreate() returns with an error this function indicates whether the error happened in the base symbology or in the composite symbol. 
/// Example: If the composite component could not be created due to wrong data this function returns true. 
/// \retval true    Error occurred during creation of the composite component
/// \retval false   Error occurred during creation of the base symbology
/// \ingroup CompSym
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
BOOL    TECIT_STDCALL       BCGet_CompSym_ErrorInCC
(
t_BarCode*  const           pBarCode            ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Returns the parity byte for QR-Code "Structured Append".
/// Returns the parity byte for a given input data-stream. Used with QR-Code and structured append.
/// \see BCSet_QR_Append()
/// \retval BYTE    Value of the parity byte
/// \ingroup QR
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
BYTE    TECIT_STDCALL       BCCalcStructApp_Parity
(
LPCSTR                      szIntData,          ///< IN:  Input data of the complete QR-Code chain
LONG                        nIntData            ///< IN:  Length of szIntData
);

///////////////////////////////////////////////////////////////////////////////
/// Returns meta-representation of a bar-code.
/// This function provides access to the meta-data of the current bar-code row (refer to BCSetFuncDrawRow()). 
/// The result of this function is only valid, when it is called in the scope of your callback function (set by BCSetFuncDrawRow()).
/// \note Sample code is available on request: support@tec-it.com
/// \retval LPCSTR  Meta-description of bar-code row. 
/// \ingroup Callback
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
LPCSTR  TECIT_STDCALL       BCGetMetaData
(
t_BarCode*  const           pBarCode            ///< IN : Pointer to bar-code structure
);

///////////////////////////////////////////////////////////////////////////////
/// Returns error text to given error-code.
/// Returns the corresponding error text for a given error code. 
/// The returned string will be null-terminated.
/// \note WINDOWS only (TBarCode DLL API)
/// \ingroup Error
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
VOID     TECIT_STDCALL      BCGetErrorText
(
ERRCODE                     eCode,              ///< IN : Error code                   
LPSTR                       szText,             ///< IO:  Error text buffer            
size_t                      nSize               ///< IN : Buffer size of szText        
);

///////////////////////////////////////////////////////////////////////////////
/// Returns extended error text to given error-code.
/// Returns the detailled error text for a given error code. The returned string will be null-terminated and contains the error-code, the error-description and the source of the error (character position) if available.
/// \note Call after BCCreate()
/// \ingroup Error
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
VOID     TECIT_STDCALL      BCGetErrorTextExt
(
t_BarCode*  const           pBarCode,           ///< IN : Pointer to bar-code structure
ERRCODE                     eCode,              ///< IN : Error code                   
LPSTR                       szText,             ///< IO : Error text buffer            
size_t                      nSize               ///< IN : Buffer size of szText        
);

///////////////////////////////////////////////////////////////////////////////
/// Gets position of invalid character in input data.
///  If BCCheck() or BCCreate() fails, this function allows you to determine the position of the first invalid character within the bar-code text (see BCSetText()). Note: The returned position may not be accurate when using Escape Sequences in the input data.
///  \retval INT     Zero-based index of invalid character. -1 if not available
/// \ingroup Error
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
INT    TECIT_STDCALL        BCGet_InvalidDataPos
(
t_BarCode*  const           pBarCode            ///< IN : Pointer to bar-code structure
);

#ifdef TBARCODE_DLL
///////////////////////////////////////////////////////////////////////////////
/// Copies bar-code to the Windows clipboard (Windows only).
/// Copies bar-code to the Windows clipboard. Call this function after BCCreate().
/// For Windows 95/98/ME: the used meta-file format (EMF) is not fully supported by these Windows versions. No problems for Windows 2000 or Windows XP are to be expected.
/// \note WINDOWS only (TBarCode DLL API)
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred. 
/// \ingroup Clipboard
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE TECIT_STDCALL       BCCopyToClipboard
(
t_BarCode*  const           pBarCode,           ///< IN : Pointer to bar-code structure
LONG                        nWidth,             ///< IN : Width of bar-code to copy, in pixels (of the physical screen)
long                        nHeight             ///< IN : Height of bar-code to copy, , in pixels (of the physical screen) 
);

///////////////////////////////////////////////////////////////////////////////
/// Copies bar-code to clipboard (extended version, Windows only).
/// Like BCCopyToClipboard(). In addition, you can specify the device context, the transparency and the background color of the resulting bar-code.
/// Optional the bar-code can be saved as EMF (Enhanced Metafile) or WMF (Windows Metafile). The format is specified through the file extension (.emf or .wmf) of szFileName.
/// Call this function after BCCreate().
/// For Windows 95/98/ME: the used meta-file format is not fully supported by these Windows versions. No problems for Windows 2000 or Windows XP are to be expected.
/// \note WINDOWS only (TBarCode DLL API)
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred. 
/// \ingroup Clipboard
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE TECIT_STDCALL       BCCopyToClipboardEx
(
t_BarCode*  const           pBarCode,           ///< IN : Pointer to bar-code structure    
HDC                         hDC,                ///< IN : Device context to copy from (default: NULL)
LONG                        nWidth,             ///< IN : Width of bar-code to copy, in pixels (of the device context)
LONG                        nHeight,            ///< IN : Height of bar-code to copy, in pixels (of the device context)
BOOL                        fTransparent,       ///< IN : Barcode transparent or not                          
                                                ///<
                                                ///< - true:    Background is not drawn
                                                ///< - false:   Background is drawn (using background color)
COLORREF                    crBkCol,            ///< IN : Background color (only if fTransparent == false)    
LPCSTR                      szFileName          ///< IN : Filename the bar-code should be written to (NULL for clipboard only)              
);

///////////////////////////////////////////////////////////////////////////////
/// Saves the bar-code to an image-file.
/// Saves the bar-code to an image-file (format Bmp, Jpg, Png, Eps, Emf...). 
/// The values of lXSize and lYSize should be increased, if the bar-code is not readable. 
/// The values of lXRes and lYRes can affect printing size when printing from graphic- or painting programs.  
/// \note WINDOWS only (TBarCode DLL API)
/// \attention Under Windows operating systems you need \c VIC32.dll in the same directory as TBarCode. If \c VIC32.dll is missing you get error-codes instead of image files.
/// \see BCSaveImageEx(), BCSaveImageToBuffer(), BCPostscriptToFile(), BCPCLToMemory(), BCGetEnhMetaFile()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred. 
/// \ingroup Save
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE TECIT_STDCALL       BCSaveImage
(
t_BarCode*  const           pBarCode,           ///< IN : Pointer to bar-code structure
LPCSTR                      lpszFileName,       ///< IN : Filename                                        
e_IMType                    eImageType,         ///< IN : Enumeration for the type of the image           
LONG                        lXSize,             ///< IN : X-Size of the image [pixel]                     
LONG                        lYSize,             ///< IN : Y-Size of the image [pixel]                     
LONG                        lXRes,              ///< IN : X-Resolution of the image [pixels / inch]       
LONG                        lYRes               ///< IN : Y-Resolution of the image [pixels / inch]       
);

///////////////////////////////////////////////////////////////////////////////
/// Saves bar-code to an image-file (extended version).
/// Saves the content of the bar-code object as image-file with respect to a specified device context (if not needed hDC can be set to 0). 
/// The values of lXSize and lYSize should be increased, if the bar-code is not readable or if the data density is high. 
/// The values of lXRes and lYRes can affect the printing size when printing from graphic- or painting programs. 
/// The image quality sets the compression algorithm (depending on the image type). 
/// With vector-EPS files you can choose between using Windows fonts (nQuality = 0) and using Postscript compatible fonts (nQuality = 1).
/// \note WINDOWS only (TBarCode DLL API)
/// \attention Under Windows operating systems you need \c VIC32.dll in the same directory as TBarCode. If \c VIC32.dll is missing you get error-codes instead of image files.
/// \see BCSaveImage(), BCSaveImageToBuffer(), BCPostscriptToFile(), BCPCLToMemory(), BCGetEnhMetaFile()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred. 
/// \ingroup Save
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE TECIT_STDCALL       BCSaveImageEx
(
t_BarCode*  const           pBarCode,           ///< IN : Pointer to bar-code structure
HDC                         hDC,                ///< IN : Device context handle (default: NULL)
LPCSTR                      lpszFileName,       ///< IN : Filename
e_IMType                    eImageType,         ///< IN : Enumeration for the type of the image
LONG                        lQuality,           ///< IN : Image Quality (meaning depends on image type)
LONG                        lXSize,             ///< IN : X-Size of the image [pixel]                     
LONG                        lYSize,             ///< IN : Y-Size of the image [pixel]                     
LONG                        lXRes,              ///< IN : X-Resolution of the image [pixels / inch]       
LONG                        lYRes               ///< IN : Y-Resolution of the image [pixels / inch]       
);

///////////////////////////////////////////////////////////////////////////////
/// Saves bar-code as image into a memory buffer.
/// Draws the bar-code and saves it using the specified image format to a memory buffer (pass a pointer variable of an arbitrary type as argument).
/// The values of XSize and YSize should be increased, if the bar-code is not readable or requires a high printing resolution. 
/// The values of XRes and YRes can affect the printing size when printing from graphic- or painting programs (but not when printing from the browser!). 
/// The buffer will be allocated on the global heap. Retrieve the buffer size in Bytes with GlobalSize((HGLOBAL)GlobalHandle(szBuffer)).
/// It is recommended to lock the buffer before reading with <i>pMem = GlobalLock (hMem)</i> and unlock it afterwards (<i>GlobalUnlock(hMem)</i>). 
/// When no longer needed the buffer must be released by calling GlobalFreePtr(buffer) (WINDOWSX.h macro).
/// \note WINDOWS only (TBarCode DLL API)
/// \attention Under Windows operating systems you need \c VIC32.dll in the same directory as TBarCode. If \c VIC32.dll is missing you get error-codes instead of image files.
/// \see BCSaveImageToBufferExt()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred. 
/// \ingroup Save
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE TECIT_STDCALL       BCSaveImageToBuffer
(
t_BarCode*  const           pBarCode,           ///< IN : Pointer to bar-code structure
LPBYTE*                     lpBuffer,           ///< OUT: Buffer                                          
e_IMType                    eImageType,         ///< IN : Enumeration for the type of the image           
LONG                        lXSize,             ///< IN : X-Size of the image [pixel]                     
LONG                        lYSize,             ///< IN : Y-Size of the image [pixel]                     
LONG                        lXRes,              ///< IN : X-Resolution of the image [pixels / inch]       
LONG                        lYRes               ///< IN : Y-Resolution of the image [pixels / inch]       
);

///////////////////////////////////////////////////////////////////////////////
/// Saves bar-code as image into a memory buffer (extended version).
/// Like BCSaveImageToBuffer() with the additional possibility to specify the image quality. For a description refer to BCSaveImageEx(). 
/// \note WINDOWS only (TBarCode DLL API)
/// \attention Under Windows operating systems you need \c VIC32.dll in the same directory as TBarCode. If \c VIC32.dll is missing you get error-codes instead of image files.
/// \see BCSaveImageToBuffer()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred. 
/// \ingroup Save
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE TECIT_STDCALL       BCSaveImageToBufferEx
(
t_BarCode*  const           pBarCode,           ///< IN : Pointer to bar-code structure
HDC                         hDC,                ///< IN : Device context (default: NULL)                  
LPBYTE*                     lpBuffer,           ///< OUT: Buffer                                          
e_IMType                    eImageType,         ///< IN : Enumeration for the type of the image           
LONG                        lQuality,           ///< IN : Image Quality (meaning depends on image type)         
LONG                        lXSize,             ///< IN : X-Size of the image [pixel]                     
LONG                        lYSize,             ///< IN : Y-Size of the image [pixel]                     
LONG                        lXRes,              ///< IN : X-Resolution of the image [pixels / inch]       
LONG                        lYRes               ///< IN : Y-Resolution of the image [pixels / inch]       
);
#endif // TBARCODE_DLL

///////////////////////////////////////////////////////////////////////////////
/// Saves bar-code as a Postscript-file.
/// Saves bar-code (in EPS-format - Encapsulated Postscript) to a file. 
/// \n
/// The origin of the coordinate space in Postscript is the lower, left corner of a page.
/// The positive y-axis points upwards.
/// \see BCPostscriptToMemory()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Save
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE TECIT_STDCALL       BCPostscriptToFile
(
t_BarCode* const            pBarCode,           ///< IN : Pointer to bar-code structure
const VOID *                szFilename,         ///< IN : Filename 
const RECT*                 pRect               ///< IN : Bounding rectangle for bar-code dimensions [1/1000 mm]
                                                ///<      left / bottom must be zero
                                                ///<      top / right specifies bar-code dimensions
);  
    
///////////////////////////////////////////////////////////////////////////////
/// Writes bar-code (Postscript) into memory-block.
/// Writes bar-code into the specified memory block. The bar-code is represented in vectorized PostScript (no bitmaps!).
/// \n
/// The origin of the coordinate space in Postscript is the lower, left corner of a page.
/// The positive y-axis points upwards.
/// \see BCPostscriptToMemoryExt()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Save
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE TECIT_STDCALL       BCPostscriptToMemory
(
t_BarCode* const            pBarCode,           ///< IN : Pointer to bar-code structure
VOID *                      pHandle,            ///< IO : Pointer to memory block 
INT                         nSize,              ///< IN : Size of memory block as allocated
const RECT*                 pRect               ///< IN : Bounding rectangle for bar-code dimensions [1/1000 mm] 
                                                ///<      left / bottom must be zero
                                                ///< IN : Dots per inch (required when resolution optimization is enabled, 
                                                ///<      see BCSetOptResolution())
);  
    
///////////////////////////////////////////////////////////////////////////////
/// Writes bar-code (Postscript) into memory-block (extended version).
/// Saves bar-code in a memory block. The bar-code is represented in vectorized PostScript (no bitmaps!). 
/// This function works like BCPostscriptToMemory() but allows additional specification of the required output resolution. 
/// Beside this it can be selected, if barcode-specific macros are to be included into the generated Postscript code.
/// \n
/// The origin of the coordinate space in Postscript is the lower, left corner of a page.
/// The positive y-axis points upwards.
/// \see BCPostscriptToMemory()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Save
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE TECIT_STDCALL       BCPostscriptToMemoryExt
(
t_BarCode* const            pBarCode,           ///< IN : Pointer to bar-code structure
VOID *                      pHandle,            ///< IN : Pointer to memory block          
INT*                        pnSize,             ///< IO : Size of memory block as allocated. Contains required size after function call.
const RECT*                 pRect,              ///< IN : Bounding rectangle [1/1000 mm]    
                                                ///<      left / bottom must be zero, top / right specifies bar-code dimensions [1/1000 mm]
BOOL                        bIncludeMacros,     ///< IN : false - exclude macro definitions 
                                                ///<     
                                                ///<      - true: Postscript Macros are included
                                                ///<      - false: Postscript Macros are excluded
INT                         nDPI                ///< IN : Dots per inch (required when resolution optimization is enabled, 
                                                ///<      see BCSetOptResolution())
);

///////////////////////////////////////////////////////////////////////////////
/// Returns Postscript macros of the Postscript code as a zero-terminated string.
/// This function is useful when embedding multiple bar-codes in a single
/// Postscript document using BCPostscriptToMemoryExt().\n
/// The Postscript codes returned by BCPostscriptToMemory() or BCPostscriptToMemoryExt()
/// internally use a series of Postscript macros. These macros are defined at the begin
/// of each bar-code. When having several bar-codes in a single Postscript document
/// the macros need to be defined only once. To achieve this the Postscript code that 
/// defines the macros can be retrieved with this function. The bar-codes can then be 
/// generated using BCPostscriptToMemoryExt() and setting bIncludeMacros to \c false.
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Save
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC
ERRCODE     TECIT_STDCALL   BCGetPostscriptMacros
(
CHAR *                       pszMacros,         ///< IN:  Pointer to a memory block
INT *                        pnSize             ///< IO : Size of memory block as allocated. Contains required size after function call.
);

///////////////////////////////////////////////////////////////////////////////
/// Saves bar-code as a PCL-file.
/// The origin of the coordinate space in PCL the is upper, left corner of a page.
/// The positive y-axis points downwards.
/// \see BCPCLToMemory()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Save
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC
ERRCODE     TECIT_STDCALL   BCPCLToFile
(
t_BarCode * const           pBarCode,           ///< IN : Pointer to bar-code structure.
const VOID *                szFilename,         ///< IN : Path and name of file.
const RECT *                pRect               ///< IN : Bounding rectangle for bar-code dimensions [1/1000 mm]
                                                ///<      (left, bottom) is the lower left corner of the bar-code (usually (0, 0)).
                                                ///<      (right, top) is the upper right corner of the bar-code.

);

///////////////////////////////////////////////////////////////////////////////
/// Saves bar-code as a PCL-file.
/// The origin of the coordinate space in PCL the is upper, left corner of a page.
/// The positive y-axis points downwards.
/// \see BCPCLToMemory()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Save
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC
ERRCODE     TECIT_STDCALL   BCPCLToFileExt
(
t_BarCode * const           pBarCode,           ///< IN : Pointer to bar-code structure.
const VOID *                szFilename,         ///< IN : Path and name of file.
const RECT *                pRect,              ///< IN : Bounding rectangle for bar-code dimensions [1/1000 mm]
                                                ///<      (left, bottom) is the lower left corner of the bar-code (usually (0, 0)).
                                                ///<      (right, top) is the upper right corner of the bar-code.
BOOL                        bRelPos,            ///< IN : Relative or absolute positioning    
                                                ///<     
                                                ///<      - \c true:   Relative positioning is used
                                                ///<      - \c false:  Absolute positioning is used
INT                         nDPI                ///< IN : Dots per inch (required when resolution optimization is enabled, 
                                                ///<      see BCSetOptResolution())
);

///////////////////////////////////////////////////////////////////////////////
/// Writes bar-code as PCL (Level 5) into memory block.
/// The origin of the coordinate space in PCL the is upper, left corner of a page.
/// The positive y-axis points downwards.
/// \see BCPCLToMemoryExt() 
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Save
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE TECIT_STDCALL       BCPCLToMemory
(
t_BarCode* const            pBarCode,           ///< IN : Pointer to bar-code structure
VOID *                      pHandle,            ///< IN : Pointer to memory block 
INT                         nSize,              ///< IN : Size of memory block as allocated
const RECT*                 pRect               ///< IN : Bounding rectangle [1/1000 mm] 
);  
    
///////////////////////////////////////////////////////////////////////////////
/// Writes bar-code as PCL Level 5 into memory block (extended version).
/// In addition to BCPCLToMemory() the required output resolution can be specified. 
/// Beside this, the parameter bRelPos switches between absolute or relative positioning.
/// \n
/// The origin of the coordinate space in PCL the is upper, left corner of a page.
/// The positive y-axis points downwards.
/// \see BCPCLToMemory() 
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Save
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE TECIT_STDCALL       BCPCLToMemoryExt
(
t_BarCode* const            pBarCode,           ///< IN : Pointer to bar-code structure
VOID *                      pHandle,            ///< IN : Pointer to memory block          
INT*                        pnSize,             ///< IO : Size of memory block as allocated. Contains required size after function call
const RECT*                 pRect,              ///< IN : Bounding rectangle [1/1000 mm]   
BOOL                        bRelPos,            ///< IN : Relative or absolute positioning    
                                                ///<     
                                                ///<      - true:   Relative positioning is used
                                                ///<      - false:  Absolute positioning is used
INT                         nDPI                ///< IN : Dots per inch (required when resolution optimization is enabled, 
                                                ///<      see BCSetOptResolution())
);

#ifdef TBARCODE_DLL
///////////////////////////////////////////////////////////////////////////////
/// Copies bar-code into metafile.
/// \attention phEMF must be released with the DeleteEnhMetaFile function if no longer used.
/// \see BCGetEnhMetaFileEx()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred. 
/// \ingroup Save
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE TECIT_STDCALL       BCGetEnhMetaFile
(
t_BarCode*  const           pBarCode,           ///< IN : Pointer to bar-code structure
HENHMETAFILE*               phEMF,              ///< OUT: Metafile handle to be drawn in  
LONG                        nWidth,             ///< IN : Width of bar-code to copy        
LONG                        nHeight             ///< IN : Height of bar-code to copy       
);  
    
///////////////////////////////////////////////////////////////////////////////
/// Copies bar-code into metafile (extended version).
/// \attention phEMF must be released with the DeleteEnhMetaFile function if no longer used.
/// \see BCGetEnhMetaFile()
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Save
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC   
ERRCODE TECIT_STDCALL       BCGetEnhMetaFileEx
(
t_BarCode*  const           pBarCode,           ///< IN : Pointer to bar-code structure
HENHMETAFILE*               phEMF,              ///< OUT: Metafile handle to be drawn in                  
HDC                         hDC,                ///< IN : Device context to copy from (default: NULL)     
LONG                        nWidth,             ///< IN : Width of bar-code to copy                        
LONG                        nHeight,            ///< IN : Height of bar-code to copy                       
BOOL                        fTransparent        ///< IN : Barcode transparent or not                      
);
#endif // TBARCODE_DLL

#ifdef LIBTBARCODE
///////////////////////////////////////////////////////////////////////////////
/// Saves bar-code as an image file (UNIX only).
/// The file name's suffix determines the image format, e.g. 'xxx.gif'.
/// Fonts are not yet supported.
/// \n
/// ImageMagick-PlugIn is required to create bitmap images.
/// ImageMagick can be downloaded from http://www.imagemagick.org/.
/// \see BCBitmapToMemory(), BCIsImageMagickAvailable()
/// \note UNIX only (TBarCode/X API).
/// \retval #ERRCODE    ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Save
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC
ERRCODE     TECIT_STDCALL   BCBitmapToFile
(
t_BarCode * const	          pBarCode,			      ///< IN : Pointer to bar-code structure
const VOID *                szFilename,         ///< IN : Path and name of file
const RECT*                 pRect,              ///< IN : Bounding rectangle for bar-code dimensions [1/1000 mm]
                                                ///<      (left, bottom) is the lower left corner of the bar-code; must be (0, 0).
                                                ///<      (right, top) is the upper right corner of the bar-code.
INT                         nDPI                ///< IN : Resolution of bitmap in dots per inch
);

///////////////////////////////////////////////////////////////////////////////
/// Writes bar-code in an image format to memory block (UNIX only).
/// Fonts are not yet supported.
/// \n
/// ImageMagick-PlugIn is required to create bitmap images.
/// ImageMagick can be downloaded from http://www.imagemagick.org/.
/// \see BCBitmapToFile(), BCIsImageMagickAvailable()
/// \note UNIX only (TBarCode/X API).
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \ingroup Save
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC
ERRCODE     TECIT_STDCALL   BCBitmapToMemory
(
t_BarCode * const	          pBarCode,			      ///< IN : Pointer to bar-code structure
VOID *                      pHandle,            ///< IN : Pointer to memory block          
LPCSTR                      pszFormat,          ///< IN : The image format: "BMP", "GIF", "JPG", ...
INT *                       pnSize,             ///< IO : Size of memory block as allocated. Contains required size after function call.
const RECT*                 pRect,              ///< IN : Bounding rectangle for bar-code dimensions [1/1000 mm]
                                                ///<      (left, bottom) is the lower left corner of the bar-code; must be (0, 0).
                                                ///<      (right, top) is the upper right corner of the bar-code.
INT                         nDPI                ///< IN : Resolution of bitmap in dots per inch
);

///////////////////////////////////////////////////////////////////////////////
/// Checks whether ImageMagick-PlugIn is available (UNIX-only).
/// ImageMagick-PlugIn is required to create bitmap images.
/// ImageMagick can be downloaded from http://www.imagemagick.org/.
/// \see BCBitmapToFile(), BCBitmapToMemory()
/// \note UNIX only (TBarCode/X API).
/// \retval BOOL   \c TRUE if ImageMagick-PlugIn is available.
/// \ingroup Save
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC
BOOL        TECIT_STDCALL   BCIsImageMagickAvailable();

///////////////////////////////////////////////////////////////////////////////
/// Unsupported (UNIX only).
/// Saves bar-code as a PDF-file. \n
/// WARNING: This function is not yet officially supported.
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \note UNIX only (TBarCode/X API).
/// \ingroup Save
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC
ERRCODE     TECIT_STDCALL   BCPDFToFile
(
t_BarCode * const           pBarCode,           ///< IN : Pointer to bar-code structure
const VOID *                szFilename,         ///< IN : Path and name of file
const RECT *                pRect               ///< IN : Bounding rectangle [1/1000 mm]    
                                                ///<      left / bottom must be zero, top / right specifies bar-code dimensions [1/1000 mm]
);

///////////////////////////////////////////////////////////////////////////////
/// Unsupported (UNIX only).
/// Writes bar-code as PDF into memory-block \n 
/// WARNING: This function is not yet officially supported.
/// \retval #ERRCODE        ErrOk (0) in case of success. Non-zero if error occurred.
/// \note UNIX only (TBarCode/X API).
/// \ingroup Save
///////////////////////////////////////////////////////////////////////////////
TECIT_DLLSPEC
ERRCODE     TECIT_STDCALL   BCPDFToMemory
(
t_BarCode * const           pBarCode,           ///< IN : Pointer to bar-code structure
VOID *                      pHandle,            ///< IN : Pointer to memory block          
INT *                       pnSize,             ///< IO : Size of memory block as allocated. Contains required size after function call.
const RECT*                 pRect,              ///< IN : Bounding rectangle [1/1000 mm]    
                                                ///<      left / bottom must be zero, top / right specifies bar-code dimensions [1/1000 mm]
INT                         nDPI                ///< IN : Dots per inch (required when resolution optimization is enabled, 
                                                ///<      see BCSetOptResolution())
);
#endif // LIBTBARCODE

#ifdef __cplusplus
  }
#endif

#endif /* HEADERFILE_TBCFUNCT_H */
